Module: GenesisRuby::Api::Constants::Transactions

Extended by:
Mixins::Constants::Common
Included in:
Utils::Transactions::FinancialTypes, Utils::Transactions::References::CapturableTypes, Utils::Transactions::References::RefundableTypes, Utils::Transactions::References::VoidableTypes, Utils::Transactions::WpfTypes
Defined in:
lib/genesis_ruby/api/constants/transactions.rb,
lib/genesis_ruby/api/constants/transactions/parameters/sca_exemptions.rb,
lib/genesis_ruby/api/constants/transactions/parameters/recurring/types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/source_of_funds.rb,
lib/genesis_ruby/api/constants/transactions/parameters/purpose_of_payment.rb,
lib/genesis_ruby/api/constants/transactions/parameters/credential_on_files.rb,
lib/genesis_ruby/api/constants/transactions/parameters/digital_asset_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/money_transfer/types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/recurring/categories.rb,
lib/genesis_ruby/api/constants/transactions/parameters/cash_payments/genders.rb,
lib/genesis_ruby/api/constants/transactions/parameters/mpi_protocol_versions.rb,
lib/genesis_ruby/api/constants/transactions/parameters/wpf/reminder_channels.rb,
lib/genesis_ruby/api/constants/transactions/parameters/business/payment_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/managed_recurring/modes.rb,
lib/genesis_ruby/api/constants/transactions/parameters/african_mobile_operators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/funding/identifier_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/mpi_protocol_sub_versions.rb,
lib/genesis_ruby/api/constants/transactions/parameters/online_banking/bank_codes.rb,
lib/genesis_ruby/api/constants/transactions/parameters/refund/bank_account_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/cash_payments/company_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/managed_recurring/intervals.rb,
lib/genesis_ruby/api/constants/transactions/parameters/non_financial/sca_exemptions.rb,
lib/genesis_ruby/api/constants/transactions/parameters/online_banking/payment_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/managed_recurring/frequencies.rb,
lib/genesis_ruby/api/constants/transactions/parameters/non_financial/processing_type.rb,
lib/genesis_ruby/api/constants/transactions/parameters/non_financial/sort_directions.rb,
lib/genesis_ruby/api/constants/transactions/parameters/online_banking/iframe_targets.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/sdk/ui_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/wallets/pay_pal/payment_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/cash_payments/marital_statuses.rb,
lib/genesis_ruby/api/constants/transactions/parameters/funding/receiver_account_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/managed_recurring/amount_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/money_transfer/source_of_funds.rb,
lib/genesis_ruby/api/constants/transactions/parameters/managed_recurring/payment_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/refund/credit_reason_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/refund/ticket_change_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/sdk/interfaces.rb,
lib/genesis_ruby/api/constants/transactions/parameters/cash_payments/cash_payment_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/mobile/apple_pay/payment_subtypes.rb,
lib/genesis_ruby/api/constants/transactions/parameters/online_banking/bank_account_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/mobile/google_pay/payment_subtypes.rb,
lib/genesis_ruby/api/constants/transactions/parameters/money_transfer/purpose_of_payments.rb,
lib/genesis_ruby/api/constants/transactions/parameters/non_financial/externally_processed.rb,
lib/genesis_ruby/api/constants/transactions/parameters/online_banking/bank_code_currencies.rb,
lib/genesis_ruby/api/constants/transactions/parameters/online_banking/payout_payment_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/travel_data/ancillary_charges_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/purchase/categories.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/browser/color_depths.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/control/device_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/non_financial/billing_api/order_by_fields.rb,
lib/genesis_ruby/api/constants/transactions/parameters/non_financial/billing_api/response_fields.rb,
lib/genesis_ruby/api/constants/transactions/parameters/money_transfer/sender_account_number_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/non_financial/billing_api/transaction_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/funding/business_application_identifier_types.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/control/challenge_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/control/challenge_window_sizes.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/merchant_risk/delivery_timeframes.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/merchant_risk/shipping_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/non_financial/billing_api/statement_response_fields.rb,
lib/genesis_ruby/api/constants/transactions/parameters/customer_identification/customer_identification_type.rb,
lib/genesis_ruby/api/constants/transactions/parameters/customer_identification/customer_identification_owner.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/card_holder_account/update_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/merchant_risk/reorder_item_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/customer_identification/customer_identification_subtype.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/card_holder_account/registration_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/merchant_risk/pre_order_purchase_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/card_holder_account/password_change_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/card_holder_account/suspicious_activity_indicators.rb,
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/card_holder_account/shipping_address_usage_indicators.rb

Overview

Available Transaction Types definitions

Defined Under Namespace

Modules: Parameters

Constant Summary collapse

ACCOUNT_VERIFICATION =

Account Verification

'account_verification'
AFRICAN_MOBILE_PAYOUT =

African Mobile Payout, or otherwise known as Disbursement, is an APM used to process Mobile network operator payments. It is an async payment method and will be approved once the payment is processed with the Mobile network operator

'african_mobile_payout'
AFRICAN_MOBILE_SALE =

African Mobile Sale, otherwise known as Charge, is an APM used to process Mobile network operator payments. It is an async payment method and will be approved once the payment is processed with the Mobile network operator

'african_mobile_sale'
ALIPAY =

Alipay is an oBeP-style alternative payment method that allows you to pay directly with your ebank account. After initiating a transaction Alipay will redirect you to their page. There you will see a picture of a QR code, which you will have to scan with your Alipay mobile application.

'alipay'
APPLE_PAY =

Apple pay is payment method working with apple devices

'apple_pay'
ARGENCARD =

Argencard is a debit or credit card used in Argentina. It allows online shoppers to pay offline for their online purchases at over 150,000 physical outlets.

'argencard'
AURA =

Aura is a local Brazilian credit card.

'aura'
AUTHORIZE =

A standard Authorization

'authorize'
AUTHORIZE_3D =

3D-Secure Authorization

'authorize3d'
BALOTO =

Baloto is a cash payment option in Colombia. It allows the customers to receive a voucher at check-out. The voucher can then be paid in any of the Via Boleto offices in cash.

'baloto'
BANCOMER =

Bancomer offers two options for payments in Mexico, cash payment and bank transfer.

'bancomer'
BANCONTACT =

Bancontact is a local Belgian debit card scheme. All Belgian debit cards are co-branded Bancontact and Maestro.

'bcmc'
BANCO_DE_OCCIDENTE =

Banco de Occidente is a cash payment method for Colombia

'banco_de_occidente'
BANCO_DO_BRASIL =

Banco do Brasil offers online bank transfer payment service.

'banco_do_brasil'
BITPAY_PAYOUT =

BitPay Payout is a crypto currency payout method where merchants are requesting payouts in FIAT currency and the funds are transfered in Bitcoin equivalent to a crypto wallet address.

'bitpay_payout'
BITPAY_REFUND =

BitPay Refund is a custom refund method which will handle the asynchronous BitPay refund workflow. BitPay refunds can only be done on former transactions. Therefore, the reference id for the corresponding BitPay Sale transaction is mandatory.

'bitpay_refund'
BITPAY_SALE =

BitPay is a cryptocurrency payments provider supporting blockchain payments with Bitcoin (BTC) and BitcoinCash (BCH).

'bitpay_sale'
BOLETO =

Boleto is a payment service in Brazil

'boleto'
BRADESCO =

Bradesco is a payment service in Brazil

'bradesco'
CABAL =

Cabal is a local debit/credit card brand in Argentina which can be used for online purchases.

'cabal'
CAPTURE =

Capture settles a transaction which has been authorized before.

'capture'
CASH =

Cash payment methods allow customers to pay bills and online purchases in cash at convenient physical locations such as stores, banks, ATMs, even pharmacies in some countries.

'cash'
CASHU =

Voucher-based payment

'cashu'
CENCOSUD =

Cencosud is a local credit card in Argentina

'cencosud'
CREDIT =

Credits (also known as Credit Fund Transfer a.k.a. CFT)

'credit'
DAVIVIENDA =

Davivienda is offering the Bill pay service which is a fast, easy and secure way to pay and manage your bills online to anyone, anytime in Colombia.

'davivienda'
EFECTY =

Efecty is an offline cash payment voucher option in Colombia.

'efecty'
ELO =

Elo is a local Brazilian payment card.

'elo'
EPS =

e-payment standard Direct PPRO transaction

'eps'
EZEECARD_PAYOUT =

eZeeCard Payout is a sync based payout method. It's merchant initiated and can only reference specific transaction types

'ezeecard_payout'
EZEEWALLET =

Wallet-based payment

'ezeewallet'
FASHIONCHEQUE =

Fashioncheque transactions are made using gift card provided by Fashioncheque. Using a fashioncheque transaction, the amount is immediately billed to the customer’s gift card. It can be reversed via a void transaction on the same day of the transaction. They can also be refunded.

'fashioncheque'
GLOBAL_PAYOUT =

Global Payout is a transaction type based on Open Banking APIs, used for initiating bank payments

'global_payout'
GOOGLE_PAY =

Google Pay allows shoppers to purchase with credit and debit cards linked to their Google account.

'google_pay'
IDEAL =

iDEAL Direct PPRO transaction

'ideal'
IDEBIT_PAYIN =

iDebit connects consumers to their online banking directly from checkout, enabling secure, real-time payments without a credit card. Using iDebit allows consumers to transfer funds to merchants without revealing their personal banking information. iDebit Payin is only asynchronous and uses eCheck.

'idebit_payin'
IDEBIT_PAYOUT =

iDebit connects consumers to their online banking directly from checkout, enabling secure, real-time payments without a credit card. Using iDebit allows consumers to transfer funds to merchants without revealing their personal banking information. iDebit Payout is only synchronous and uses eCheck.

'idebit_payout'
INCREMENTAL_AUTHORIZE =

Incremental authorizations are used in preauthorization workflow to extend the preauthorization amount, extend the preauthorization time-frame

'incremental_authorize'
INIT_RECURRING_SALE =
Deprecated.

Since 0.1.0 Payment method is deprecated and will be removed

A standard initial recurring

'init_recurring_sale'
INIT_RECURRING_SALE_3D =
Deprecated.

Since 0.1.0 Payment method is deprecated and will be removed

3D-based initial recurring

'init_recurring_sale3d'
INSTA_DEBIT_PAYIN =

InstaDebit connects consumers to their online banking directly from checkout, enabling secure, real- time payments without a credit card. Using InstaDebit allows consumers to transfer funds to merchants without revealing their personal banking information. InstaDebit Payin is only asynchronous and uses online bank transfer.

'insta_debit_payin'
INSTA_DEBIT_PAYOUT =

InstaDebit connects consumers to their online banking directly from checkout, enabling secure, real- time payments without a credit card. Using InstaDebit allows consumers to transfer funds to merchants without revealing their personal banking information. InstaDebit Payout is only synchronous and uses online bank transfer.

'insta_debit_payout'
INTERSOLVE =

Intersolve transactions are made using gift card provided by Intersolve Using a intersolve transaction, the amount is immediately billed to the customer’s gift card. It can be reversed via a void transaction.

'intersolve'
INVOICE =

Alternative payments refer to payment methods that are used as an alternative to credit card payments. Each alternative payment method has its own unique application, settlement process and currency support.

'invoice'
INVOICE_CAPTURE =

A Invoice capture can only be used after a Invoice on the same transaction.

'invoice_capture'
INVOICE_REFUND =

The amount can be fully or partially refunded. Invoice refunds can only be done on former Invoice Capture (settled) transactions.

'invoice_refund'
ITAU =

Itau is a real-time online bank transfer method and a virtual card.

'itau'
MULTIBANCO =

Multibanco allows Portuguese shoppers to do payments through the Internet by using virtual credit cards

'multibanco'
MY_BANK =

My Bank is an overlay banking system

'my_bank'
NARANJA =

Naranja is a local credit card issued in Argentina which can be used for purchases over the internet.

'naranja'
NATIVA =

Nativa is an Argentinian credit card provided by the National Bank of Argentina.

'nativa'
NEOSURF =

Neosurf is a prepaid card (voucher) that is used for online shopping. The card is available in over 100,000 stores worldwide, where customers can buy the prepaid vouchers, denominated up to EUR 250.00 or its equivalent in other currencies.

'neosurf'
NETELLER =

Neteller

'neteller'
ONLINE_BANKING_PAYIN =

Online Banking is an oBeP-style alternative payment method that allows you to pay directly with your ebank account. After initiating a transaction, the online banking will redirect you to their page. There you will find a list with available banks to finish the payment.

'online_banking'
ONLINE_BANKING_PAYOUT =

Bank Pay-out is a bank pay-out method. It allows merchants to transfer funds directly to customers’ bank accounts.

'bank_payout'
OXXO =

OXXO is the preferred payment method in Mexico. It is a cash payment via a barcode document thats accepted in more than 14,000 stores.

'oxxo'
P24 =

P24 is an online banking payment, popular in Poland

'p24'
PAGO_FACIL =

Pago Facil is a payment service in Argentina that allows its users to send money, top up their cell phone and payments.

'pago_facil'
PARTIAL_REVERSAL =

Partial reversal transactions are used in preauthorization workflow to release a part of the total authorized amount before a partial capture to be submitted. A transaction of this type should refer the preauthorization directly.

'partial_reversal'
PAYBYVOUCHER_YEEPAY =
Deprecated.

Payment method is deprecated and will be removed

PayByVouchers via oBeP

'paybyvoucher_yeepay'
PAYOUT =

Payouts transactions

'payout'
PAYSAFECARD =

Voucher-based payment

'paysafecard'
PAYU =

PayU is a payment method for Czech Republic and Poland

'payu'
PAY_PAL =

PayPal transaction is a fast and easy way for buyers to pay with their PayPal account. It gives buyers all the transaction details at once, including order details, shipping options, insurance choices, and tax totals.

'pay_pal'
PIX =

Pix is a payment service created by the Central Bank of Brazil (BACEN), which represents a new way of receiving/sending money. Pix allows payments to be made instantly. The customer can pay bills, invoices, public utilities, transfer and receive credits in a facilitated manner, using only Pix keys (CPF/CNPJ).

'pix'
POLI =

POLi is Australia's most popular online real time debit payment system.

'poli'
POST_FINANCE =

PostFinance is an online banking provider in Switzerland

'post_finance'
PPRO =

Supports payments via EPS, SafetyPay, TrustPay, ELV, Przelewy24

'ppro'
PSE =

PSE (Pagos Seguros en Linea) is the preferred alternative payment solution in Colombia. The solution consists of an interface that offers the client the option to pay for their online purchases in cash, directing it to their online banking.

'pse'
RAPI_PAGO =

RapiPago from Argentina is an offline payment method used for online purchases. Shoppers buy their goods and services online and pay offline at one of the 6,000+ RapiPago payment locations.

'rapi_pago'
RECURRING_SALE =
Deprecated.

Since 0.1.0 Payment method is deprecated and will be removed

A RecurringSale transaction is a "repeated" transaction which follows and references an initial transaction

'recurring_sale'
REDPAGOS =

Redpagos is a cash payment in Uruguay

'redpagos'
REFUND =

Refunds allow to return already billed amounts to customers.

'refund'
RUSSIAN_MOBILE_PAYOUT =

Russian Mobile Payout, or otherwise known as Disbursement, is an APM used to process Mobile network operator payments. It is an async payment method and will be approved once the payment is processed by the Mobile network operator. Notice: Russian Mobile Payout does not support refund and void.

'russian_mobile_payout'
RUSSIAN_MOBILE_SALE =

Russian Mobile Sale, otherwise known as Charge, is an APM used to process Mobile network operator payments. It is an async payment method and will be approved once the payment is processed by the Mobile network operator. Notice: Russian Mobile Sale does not support refund and void.

'russian_mobile_sale'
SAFETYPAY =

Safetypay is a real-time bank transfer system that operates in more than 10 different countries. Their main market is in Latin America.

'safetypay'
SALE =

A standard Sale

'sale'
SALE_3D =

3D-Secure Sale

'sale3d'
SANTANDER =

Santander is an online bank transfer for ecommerce purchases. Consumers use their trusted home banking environment, merchants benefit from payment guarantee and swift settlement.

'santander'
SCT_PAYOUT =

Sepa Direct Debit Payout, popular in Germany. Processed as a SEPA CreditTransfer and can be used for all kind of payout services across the EU with 1 day settlement. Suitable for Gaming, Forex-Binaries, Affiliate Programs or Merchant payouts

'sct_payout'
SDD_INIT_RECURRING_SALE =

Sepa Direct Debit initial recurring

'sdd_init_recurring_sale'
SDD_RECURRING_SALE =

Sepa Direct Debit RecurringSale transaction is a "repeated" transaction, which follows and references an SDD initial transaction

'sdd_recurring_sale'
SDD_REFUND =

Sepa Direct Debit Refund Transaction. Refunds allow to return already billed amounts to customers.

'sdd_refund'
SDD_SALE =

Sepa Direct Debit Payment, popular in Germany. Single Euro Payments Area (SEPA) allows consumers to make cashless Euro payments to any beneficiary located anywhere in the Euro area using only a single bank account

'sdd_sale'
SOFORT =

Bank transfer payment, popular in Germany

'sofort'
TARJETA_SHOPPING =

Tarjeta Shopping is a cash payment in Argentina.

'tarjeta_shopping'
TCS =

TCS Thecontainerstore transactions are made using gift cards provided by TCS The amount from a Container Store Transactions is immediately billed to the customer’s gift card. It can be reversed via a void transaction.

'container_store'
TRANSFER_TO_PAYOUT =

TransferTo Payout is an APM which provides 3 different payment services: BankAccount, MobileWallet and CashPickup. Merchant sends money to a consumer.

'transfer_to_payout'
TRUSTLY_SALE =

Trustly is a fast and secure oBeP-style alternative payment method. It is free of charge and allows you to deposit money directly from your online bank account.

'trustly_sale'
UPI =

UPI (Unified Payment Interface) transaction is an alternative payment method which allows users to transfer money between bank accounts.

'upi'
VOID =

Void transactions undo previous transactions.

'void'
WEBMONEY =

WebMoney is a global settlement system and environment for online business activities.

'webmoney'
WEBPAY =

Webpay is a Chilean real-time bank transfer method.

'webpay'
WECHAT =

WeChat Pay solution offers merchants access to the over 300 million WeChat users that have linked payment to their WeChat account. The solution works on desktop and mobile via a QR code generation platform.

'wechat'

Method Summary

Methods included from Mixins::Constants::Common

all, valid?