Class: GenesisRuby::Api::Constants::Transactions::Parameters::PurposeOfPayment

Inherits:
Object
  • Object
show all
Extended by:
Mixins::Constants::Common
Defined in:
lib/genesis_ruby/api/constants/transactions/parameters/purpose_of_payment.rb

Overview

Purpose of Payment

Constant Summary collapse

ISINTE =

Interest

'ISINTE'
ISINTX =

Income tax

'ISINTX'
ISINVS =

Investment

'ISINVS'
ISLBRI =

Labor insurance

'ISLBRI'
ISLICF =

License fee

'ISLICF'
ISLIFI =

Life insurance

'ISLIFI'
ISLOAN =

Loan

'ISLOAN'
ISMDCS =

Medical services

'ISMDCS'
ISMP2B =

Mobile P2B payment

'ISMP2B'
ISMP2P =

Mobile P2P payment

'ISMP2P'
ISMTUP =

Mobile top up

'ISMTUP'
ISNOWS =

Not otherwise specified

'ISNOWS'
ISOTHR =

Other

'ISOTHR'
ISOTLC =

Transaction is related to a payment of other telecom related bill

'ISOTLC'
ISPAYR =

Payroll

'ISPAYR'
ISPEFC =

Contribution to pension fund

'ISPEFC'
ISPENS =

Pension payment

'ISPENS'
ISPHON =

Payment of telephone bill

'ISPHON'
ISPPTI =

Property insurance

'ISPPTI'
ISRELG =

Transaction is for general rental/lease

'ISRELG'
ISRENT =

The payment of rent

'ISRENT'
ISRLWY =

Payment for railway transport related business

'ISRLWY'
ISROYA =

Royalties

'ISROYA'
ISSALA =

Salary payment

'ISSALA'
ISSAVG =

Payment to savings/retirement account

'ISSAVG'
ISSECU =

Securities

'ISSECU'
ISSSBE =

Social security benefit

'ISSSBE'
ISSTDY =

Study

'ISSTDY'
ISSUBS =

Subscription

'ISSUBS'
ISSUPP =

Supplier payment

'ISSUPP'
ISTAXR =

Refund of a tax payment or obligation

'ISTAXR'
ISTAXS =

Tax payment

'ISTAXS'
ISTBIL =

Transaction is related to a payment of telecommunications related bill

'ISTBIL'
ISTRAD =

Trade services operation

'ISTRAD'
ISTREA =

Treasury payment

'ISTREA'
ISTRPT =

Payment for travel

'ISTRPT'
ISUBIL =

Utility bill payment

'ISUBIL'
ISVATX =

Value added tax payment

'ISVATX'
ISWHLD =

With holding

'ISWHLD'
ISWTER =

Payment of water bill

'ISWTER'

Method Summary

Methods included from Mixins::Constants::Common

all, valid?