Class: GenesisRuby::Api::Constants::Transactions::Parameters::Threeds::Version2::Control::ChallengeIndicators

Inherits:
Object
  • Object
show all
Extended by:
Mixins::Constants::Common
Defined in:
lib/genesis_ruby/api/constants/transactions/parameters/threeds/version2/control/challenge_indicators.rb

Overview

Threeds Version2 Control Challenge Indicators

Constant Summary collapse

NO_PREFERENCE =

Don't have any preferences related to the Challenge flow (default)

'no_preference'
NO_CHALLENGE_REQUESTED =

I prefer that a Challenge flow does not take place

'no_challenge_requested'
PREFERENCE =

A request for the Challenge flow to take place

'preference'
MANDATE =

A Challenge flow must take place to fulfill a mandate

'mandate'

Method Summary

Methods included from Mixins::Constants::Common

all, valid?