Module: GenesisRuby::Api::Mixins::Requests::Financial::Threeds::Version2::CardHolderAccount

Included in:
CommonAttributes, WpfAttributes
Defined in:
lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb

Overview

Mixin ThreedsV2 Card holder Account

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#threeds_v2_card_holder_account_password_change_indicatorObject

Returns the value of attribute threeds_v2_card_holder_account_password_change_indicator.



26
27
28
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 26

def 
  @threeds_v2_card_holder_account_password_change_indicator
end

#threeds_v2_card_holder_account_provision_attempts_last24_hoursObject

rubocop:disable Metrics/ModuleLength



22
23
24
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 22

def 
  @threeds_v2_card_holder_account_provision_attempts_last24_hours
end

#threeds_v2_card_holder_account_purchases_count_last6_monthsObject

rubocop:disable Metrics/ModuleLength



22
23
24
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 22

def 
  @threeds_v2_card_holder_account_purchases_count_last6_months
end

#threeds_v2_card_holder_account_registration_indicatorObject

Returns the value of attribute threeds_v2_card_holder_account_registration_indicator.



26
27
28
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 26

def 
  @threeds_v2_card_holder_account_registration_indicator
end

#threeds_v2_card_holder_account_shipping_address_usage_indicatorObject

Returns the value of attribute threeds_v2_card_holder_account_shipping_address_usage_indicator.



26
27
28
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 26

def 
  @threeds_v2_card_holder_account_shipping_address_usage_indicator
end

#threeds_v2_card_holder_account_suspicious_activity_indicatorObject

Returns the value of attribute threeds_v2_card_holder_account_suspicious_activity_indicator.



26
27
28
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 26

def 
  @threeds_v2_card_holder_account_suspicious_activity_indicator
end

#threeds_v2_card_holder_account_transactions_activity_last24_hoursObject

rubocop:disable Metrics/ModuleLength



22
23
24
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 22

def 
  @threeds_v2_card_holder_account_transactions_activity_last24_hours
end

#threeds_v2_card_holder_account_transactions_activity_previous_yearObject

rubocop:disable Metrics/ModuleLength



22
23
24
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 22

def 
  @threeds_v2_card_holder_account_transactions_activity_previous_year
end

#threeds_v2_card_holder_account_update_indicatorObject

Returns the value of attribute threeds_v2_card_holder_account_update_indicator.



26
27
28
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 26

def 
  @threeds_v2_card_holder_account_update_indicator
end

Instance Method Details

#threeds_v2_card_holder_account_creation_dateObject

Date that the cardholder opened the account with the 3DS Requester.



33
34
35
36
37
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 33

def 
  @threeds_v2_card_holder_account_creation_date&.strftime(
    GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS
  )
end

#threeds_v2_card_holder_account_creation_date=(value) ⇒ Object

Date that the cardholder opened the account with the 3DS Requester.



40
41
42
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 40

def (value)
  parse_date attribute: __method__, value: value, allow_empty: true
end

#threeds_v2_card_holder_account_last_change_dateObject

Date that the cardholder’s account with the 3DS Requester was last changed



45
46
47
48
49
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 45

def 
  @threeds_v2_card_holder_account_last_change_date&.strftime(
    GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS
  )
end

#threeds_v2_card_holder_account_last_change_date=(value) ⇒ Object

Date that the cardholder’s account with the 3DS Requester was last changed



52
53
54
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 52

def (value)
  parse_date attribute: __method__, value: value, allow_empty: true
end

#threeds_v2_card_holder_account_password_change_dateObject

Date that cardholder’s account with the 3DS Requester had a password change or account reset



57
58
59
60
61
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 57

def 
  @threeds_v2_card_holder_account_password_change_date&.strftime(
    GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS
  )
end

#threeds_v2_card_holder_account_password_change_date=(value) ⇒ Object

Date that cardholder’s account with the 3DS Requester had a password change or account reset



64
65
66
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 64

def (value)
  parse_date attribute: __method__, value: value, allow_empty: true
end

#threeds_v2_card_holder_account_registration_dateObject

Date that the cardholder opened the account with the 3DS Requester.



101
102
103
104
105
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 101

def 
  @threeds_v2_card_holder_account_registration_date&.strftime(
    GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS
  )
end

#threeds_v2_card_holder_account_registration_date=(value) ⇒ Object

Date that the payment account was enrolled in the cardholder’s account with the 3DS Requester



108
109
110
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 108

def (value)
  parse_date attribute: __method__, value: value, allow_empty: true
end

#threeds_v2_card_holder_account_shipping_address_date_first_usedObject

Date when the shipping address used for this transaction was first used with the 3DS Requester



69
70
71
72
73
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 69

def 
  @threeds_v2_card_holder_account_shipping_address_date_first_used&.strftime(
    GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS
  )
end

#threeds_v2_card_holder_account_shipping_address_date_first_used=(value) ⇒ Object

Date when the shipping address used for this transaction was first used with the 3DS Requester



76
77
78
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/card_holder_account.rb', line 76

def (value)
  parse_date attribute: __method__, value: value, allow_empty: true
end