Module: GenesisRuby::Api::Mixins::Requests::Financial::Threeds::Version2::Recurring

Included in:
CommonAttributes, WpfAttributes
Defined in:
lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/recurring.rb

Overview

Mixin ThreedsV2 Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#threeds_v2_recurring_frequencyObject

Returns the value of attribute threeds_v2_recurring_frequency.



13
14
15
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/recurring.rb', line 13

def threeds_v2_recurring_frequency
  @threeds_v2_recurring_frequency
end

Instance Method Details

#threeds_v2_recurring_expiration_dateObject

A future date indicating the end date for any further subsequent transactions



16
17
18
19
20
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/recurring.rb', line 16

def threeds_v2_recurring_expiration_date
  @threeds_v2_recurring_expiration_date&.strftime(
    GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS
  )
end

#threeds_v2_recurring_expiration_date=(value) ⇒ Object

A future date indicating the end date for any further subsequent transactions



23
24
25
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/recurring.rb', line 23

def threeds_v2_recurring_expiration_date=(value)
  parse_date attribute: __method__, value: value, allow_empty: true
end