Module: GenesisRuby::Api::Mixins::Requests::Financial::Threeds::Version2::Sdk

Included in:
CommonAttributes
Defined in:
lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb

Overview

Mixin ThreedsV2 SDK

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#threeds_v2_sdk_application_idObject

Returns the value of attribute threeds_v2_sdk_application_id.



17
18
19
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb', line 17

def threeds_v2_sdk_application_id
  @threeds_v2_sdk_application_id
end

#threeds_v2_sdk_encrypted_dataObject

Returns the value of attribute threeds_v2_sdk_encrypted_data.



17
18
19
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb', line 17

def threeds_v2_sdk_encrypted_data
  @threeds_v2_sdk_encrypted_data
end

#threeds_v2_sdk_ephemeral_public_key_pairObject

Returns the value of attribute threeds_v2_sdk_ephemeral_public_key_pair.



17
18
19
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb', line 17

def threeds_v2_sdk_ephemeral_public_key_pair
  @threeds_v2_sdk_ephemeral_public_key_pair
end

#threeds_v2_sdk_interfaceObject

Returns the value of attribute threeds_v2_sdk_interface.



20
21
22
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb', line 20

def threeds_v2_sdk_interface
  @threeds_v2_sdk_interface
end

#threeds_v2_sdk_max_timeoutObject

Returns the value of attribute threeds_v2_sdk_max_timeout.



17
18
19
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb', line 17

def threeds_v2_sdk_max_timeout
  @threeds_v2_sdk_max_timeout
end

#threeds_v2_sdk_reference_numberObject

Returns the value of attribute threeds_v2_sdk_reference_number.



17
18
19
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb', line 17

def threeds_v2_sdk_reference_number
  @threeds_v2_sdk_reference_number
end

Instance Method Details

#threeds_v2_sdk_ui_typesObject

UI type that the device of the consumer supports for displaying specific challenge interface



23
24
25
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb', line 23

def threeds_v2_sdk_ui_types
  @threeds_v2_sdk_ui_types ||= []
end

#threeds_v2_sdk_ui_types=(value) ⇒ Object

UI type that the device of the consumer supports for displaying specific challenge interface



28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/sdk.rb', line 28

def threeds_v2_sdk_ui_types=(value)
  ui_types = GenesisRuby::Api::Constants::Transactions::Parameters::Threeds::Version2::Sdk::UiTypes

  unless ui_types.valid?(value)
    raise InvalidArgumentError, format(
      'Invalid value given for %{method}. Allowed values: %{allowed}',
      method:  __method__,
      allowed: ui_types.all
    )
  end

  threeds_v2_sdk_ui_types.push value.to_s.downcase
end