Module: GenesisRuby::Api::Mixins::Requests::NonFinancial::Kyc::VerificationDocumentAttributes
- Included in:
- Requests::NonFinancial::Kyc::Verifications::Create
- Defined in:
- lib/genesis_ruby/api/mixins/requests/non_financial/kyc/verification_document_attributes.rb
Overview
Data used by the document verification service to check the authenticity of identity documents submitted by customers
Instance Attribute Summary collapse
-
#document_allow_offline ⇒ Object
Returns the value of attribute document_allow_offline.
-
#document_allow_online ⇒ Object
Returns the value of attribute document_allow_online.
-
#document_first_name ⇒ Object
Returns the value of attribute document_first_name.
-
#document_last_name ⇒ Object
Returns the value of attribute document_last_name.
Instance Method Summary collapse
-
#document_date_of_birth ⇒ Object
Customer's date of birth.
-
#document_date_of_birth=(value) ⇒ Object
Customer's date of birth.
Instance Attribute Details
#document_allow_offline ⇒ Object
Returns the value of attribute document_allow_offline.
14 15 16 |
# File 'lib/genesis_ruby/api/mixins/requests/non_financial/kyc/verification_document_attributes.rb', line 14 def document_allow_offline @document_allow_offline end |
#document_allow_online ⇒ Object
Returns the value of attribute document_allow_online.
14 15 16 |
# File 'lib/genesis_ruby/api/mixins/requests/non_financial/kyc/verification_document_attributes.rb', line 14 def document_allow_online @document_allow_online end |
#document_first_name ⇒ Object
Returns the value of attribute document_first_name.
13 14 15 |
# File 'lib/genesis_ruby/api/mixins/requests/non_financial/kyc/verification_document_attributes.rb', line 13 def document_first_name @document_first_name end |
#document_last_name ⇒ Object
Returns the value of attribute document_last_name.
13 14 15 |
# File 'lib/genesis_ruby/api/mixins/requests/non_financial/kyc/verification_document_attributes.rb', line 13 def document_last_name @document_last_name end |
Instance Method Details
#document_date_of_birth ⇒ Object
Customer's date of birth
17 18 19 20 21 |
# File 'lib/genesis_ruby/api/mixins/requests/non_financial/kyc/verification_document_attributes.rb', line 17 def document_date_of_birth @document_date_of_birth&.strftime( GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 ) end |
#document_date_of_birth=(value) ⇒ Object
Customer's date of birth
24 25 26 |
# File 'lib/genesis_ruby/api/mixins/requests/non_financial/kyc/verification_document_attributes.rb', line 24 def document_date_of_birth=(value) parse_date attribute: __method__, value: value, allow_empty: true end |