Class: GenesisRuby::Api::Requests::Financial::Cards::Authorize3d

Overview

Authorize 3D transactions, credit card based, can be synchronous or asynchronous based on the workflow and the additional parameters for card holder authentication

Constant Summary

Constants included from Mixins::Requests::Financial::Cards::AccountOwnerAttributes

Mixins::Requests::Financial::Cards::AccountOwnerAttributes::ACCOUNT_NAME_LENGTH

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary

Attributes included from Mixins::Requests::Financial::TravelData::ReferenceTicketAttributes

#travel_ac_issued_with_ticket_number, #travel_ac_sub_type, #travel_ac_ticket_document_number, #travel_ac_ticket_reference_id, #travel_ac_type

Attributes included from Mixins::Requests::Financial::TravelData::HotelRentalAttributes

#travel_hotel_rental_customer_code, #travel_hotel_rental_extra_charges, #travel_hotel_rental_no_show_indicator, #travel_hotel_rental_purchase_identifier

Attributes included from Mixins::Requests::Financial::TravelData::CarRentalAttributes

#travel_car_rental_class_id, #travel_car_rental_customer_code, #travel_car_rental_extra_charges, #travel_car_rental_no_show_indicator, #travel_car_rental_purchase_identifier, #travel_car_rental_renter_name, #travel_car_rental_renter_return_location_id, #travel_car_rental_return_city, #travel_car_rental_return_country, #travel_car_rental_return_state

Attributes included from Mixins::Requests::Financial::TravelData::AirlineItineraryAttributes

#travel_aid_agency_code, #travel_aid_agency_name, #travel_aid_confirmation_information, #travel_aid_customer_code, #travel_aid_issuing_carrier, #travel_aid_passenger_name, #travel_aid_restricted_ticket_indicator, #travel_aid_ticket_number, #travel_aid_total_fare

Attributes included from Mixins::Requests::Financial::Threeds::Version2::Sdk

#threeds_v2_sdk_application_id, #threeds_v2_sdk_encrypted_data, #threeds_v2_sdk_ephemeral_public_key_pair, #threeds_v2_sdk_interface, #threeds_v2_sdk_max_timeout, #threeds_v2_sdk_reference_number

Attributes included from Mixins::Requests::Financial::Threeds::Version2::Recurring

#threeds_v2_recurring_frequency

Attributes included from Mixins::Requests::Financial::Threeds::Version2::Purchase

#threeds_v2_purchase_category

Attributes included from Mixins::Requests::Financial::Threeds::Version2::Method

#threeds_v2_method_callback_url

Attributes included from Mixins::Requests::Financial::Threeds::Version2::MerchantRisk

#threeds_v2_merchant_risk_delivery_timeframe, #threeds_v2_merchant_risk_gift_card, #threeds_v2_merchant_risk_gift_card_count, #threeds_v2_merchant_risk_pre_order_purchase_indicator, #threeds_v2_merchant_risk_reorder_items_indicator, #threeds_v2_merchant_risk_shipping_indicator

Attributes included from Mixins::Requests::Financial::Threeds::Version2::Control

#threeds_v2_control_challenge_indicator, #threeds_v2_control_challenge_window_size, #threeds_v2_control_device_type

Attributes included from Mixins::Requests::Financial::Threeds::Version2::CardHolderAccount

#threeds_v2_card_holder_account_password_change_indicator, #threeds_v2_card_holder_account_provision_attempts_last24_hours, #threeds_v2_card_holder_account_purchases_count_last6_months, #threeds_v2_card_holder_account_registration_indicator, #threeds_v2_card_holder_account_shipping_address_usage_indicator, #threeds_v2_card_holder_account_suspicious_activity_indicator, #threeds_v2_card_holder_account_transactions_activity_last24_hours, #threeds_v2_card_holder_account_transactions_activity_previous_year, #threeds_v2_card_holder_account_update_indicator

Attributes included from Mixins::Requests::Financial::Threeds::Version2::Browser

#threeds_v2_browser_accept_header, #threeds_v2_browser_color_depth, #threeds_v2_browser_java_enabled, #threeds_v2_browser_language, #threeds_v2_browser_screen_height, #threeds_v2_browser_screen_width, #threeds_v2_browser_time_zone_offset, #threeds_v2_browser_user_agent

Attributes included from Mixins::Requests::Financial::ScaAttributes

#sca_exemption, #sca_visa_merchant_id

Attributes included from Mixins::Requests::Financial::RiskAttributes

#risk_bin, #risk_bin_name, #risk_bin_phone, #risk_country, #risk_email, #risk_first_name, #risk_forwarded_ip, #risk_last_name, #risk_mac_address, #risk_pan, #risk_pan_tail, #risk_password, #risk_phone, #risk_remote_ip, #risk_serial_number, #risk_session_id, #risk_ssn, #risk_user_id, #risk_user_level, #risk_username

Attributes included from Mixins::Requests::Financial::PreauthorizationAttributes

#preauthorization

Attributes included from Mixins::Requests::Financial::NotificationAttributes

#notification_url

Attributes included from Mixins::Requests::Financial::MotoAttributes

#moto

Attributes included from Mixins::Requests::Financial::GamingAttributes

#gaming

Attributes included from Mixins::Requests::Financial::FundingAttributes

#funding_business_application_identifier, #funding_identifier_type, #funding_receiver_account_number, #funding_receiver_account_number_type, #funding_receiver_address, #funding_receiver_city, #funding_receiver_country, #funding_receiver_first_name, #funding_receiver_last_name, #funding_receiver_state, #funding_sender_address, #funding_sender_city, #funding_sender_country, #funding_sender_name, #funding_sender_reference_number, #funding_sender_state

Attributes included from Mixins::Requests::Financial::DynamicDescriptorAttributes

#dynamic_descriptor_merchant_address, #dynamic_descriptor_merchant_city, #dynamic_descriptor_merchant_country, #dynamic_descriptor_merchant_geo_coordinates, #dynamic_descriptor_merchant_name, #dynamic_descriptor_merchant_phone, #dynamic_descriptor_merchant_service_city, #dynamic_descriptor_merchant_service_country, #dynamic_descriptor_merchant_service_geo_coordinates, #dynamic_descriptor_merchant_service_phone, #dynamic_descriptor_merchant_service_state, #dynamic_descriptor_merchant_service_zip_code, #dynamic_descriptor_merchant_state, #dynamic_descriptor_merchant_url, #dynamic_descriptor_merchant_zip_code, #dynamic_descriptor_sub_merchant_id

Attributes included from Mixins::Requests::Financial::CryptoAttributes

#crypto

Attributes included from Mixins::Requests::Financial::Cards::Recurring::RecurringTypeAttributes

#recurring_type

Attributes included from Mixins::Requests::Financial::Cards::Recurring::RecurringCategoryAttributes

#recurring_category

Attributes included from Mixins::Requests::Financial::Cards::Recurring::ManagedRecurringAttributes

#managed_recurring_amount, #managed_recurring_interval, #managed_recurring_max_count, #managed_recurring_mode, #managed_recurring_period, #managed_recurring_time_of_day

Attributes included from Mixins::Requests::Financial::Cards::Recurring::ManagedRecurringIndianCardAttributes

#managed_recurring_amount_type, #managed_recurring_frequency, #managed_recurring_max_amount, #managed_recurring_payment_type, #managed_recurring_registration_reference_number, #managed_recurring_validated

Attributes included from Mixins::Requests::Financial::Cards::MpiAttributes

#mpi_asc_transaction_id, #mpi_cavv, #mpi_directory_server_id, #mpi_eci, #mpi_protocol_sub_version, #mpi_protocol_version, #mpi_threeds_challenge_indicator, #mpi_xid

Attributes included from Mixins::Requests::Financial::Cards::InstallmentAttributes

#installment_plan_id, #installment_plan_reference

Attributes included from Mixins::Requests::Financial::Cards::FxRateAttributes

#fx_rate_id

Attributes included from Mixins::Requests::Financial::Business::BusinessAttributes

#business_payment_type

Attributes included from Mixins::Requests::Financial::Business::TravelAgenciesAttributes

#business_atol_certificate, #business_carrier_code, #business_contractor_name, #business_destination_city, #business_flight_number, #business_origin_city, #business_ticket_number, #business_travel_agency

Attributes included from Mixins::Requests::Financial::Business::HotelsAndRealEstateRentalsAttributes

#business_travel_agency_name

Attributes included from Mixins::Requests::Financial::Business::FurnitureAttributes

#business_name_of_the_supplier

Attributes included from Mixins::Requests::Financial::Business::EventManagementAttributes

#business_event_id, #business_event_organizer_id

Attributes included from Mixins::Requests::Financial::Business::CarPlaneAndBoatRentalsAttributes

#business_supplier_name

Attributes included from Mixins::Requests::Financial::Business::AirlinesAirCarriersAttributes

#business_airline_code, #business_airline_flight_number, #business_airline_tour_operator_name, #business_flight_destination_city, #business_flight_origin_city, #business_flight_ticket_number

Attributes included from Mixins::Requests::Financial::AsyncAttributes

#return_failure_url, #return_success_url

Attributes included from Mixins::Requests::DocumentAttributes

#document_id

Attributes included from Mixins::Requests::DigitalAssetTypeAttributes

#digital_asset_type

Attributes included from Mixins::Requests::CustomerAddress::CustomerInfoAttributes

#customer_email, #customer_phone

Attributes included from Mixins::Requests::CustomerAddress::ShippingInfoAttributes

#shipping_address1, #shipping_address2, #shipping_city, #shipping_country, #shipping_first_name, #shipping_last_name, #shipping_neighborhood, #shipping_state, #shipping_zip_code

Attributes included from Mixins::Requests::CustomerAddress::BillingInfoAttributes

#billing_address1, #billing_address2, #billing_city, #billing_country, #billing_first_name, #billing_last_name, #billing_neighborhood, #billing_state, #billing_zip_code

Attributes inherited from Base::Financials::CreditCard

#scheme_tokenized

Attributes included from Mixins::Requests::Financial::Cards::UcofAttributes

#credential_on_file_transaction_identifier

Attributes included from Mixins::Requests::Financial::Cards::TokenizationParamsAttributes

#tokenization_eci, #tokenization_tavv

Attributes included from Mixins::Requests::Financial::Cards::TokenizationAttributes

#consumer_id, #remember_card, #token

Attributes included from Mixins::Requests::Financial::Cards::CreditCardAttributes

#card_holder, #card_number, #cvv, #expiration_month, #expiration_year

Attributes included from Mixins::Requests::Financial::Cards::CredentialOnFileAttributes

#credential_on_file

Attributes included from Mixins::Requests::Financial::Cards::AccountOwnerAttributes

#account_first_name, #account_last_name, #account_middle_name

Attributes included from Mixins::Requests::Financial::PaymentAttributes

#amount, #currency

Attributes included from Mixins::Requests::Financial::BaseAttributes

#remote_ip, #transaction_id, #usage

Attributes inherited from GenesisRuby::Api::Request

#api_config

Method Summary

Methods included from Mixins::Requests::Financial::TravelData::HotelRentalAttributes

#travel_hotel_rental_arrival_date, #travel_hotel_rental_arrival_date=, #travel_hotel_rental_departure_date, #travel_hotel_rental_departure_date=

Methods included from Mixins::Requests::Financial::TravelData::CarRentalAttributes

#travel_car_rental_pickup_date, #travel_car_rental_pickup_date=, #travel_car_rental_return_date, #travel_car_rental_return_date=

Methods included from Mixins::Requests::Financial::TravelData::AirlineItineraryAttributes

#add_travel_aid_leg, #add_travel_aid_tax, #clear_travel_aid_legs, #clear_travel_aid_taxes, #travel_aid_date_of_issue, #travel_aid_date_of_issue=, #travel_aid_legs, #travel_aid_taxes

Methods included from Mixins::Requests::Financial::Threeds::Version2::Sdk

#threeds_v2_sdk_ui_types, #threeds_v2_sdk_ui_types=

Methods included from Mixins::Requests::Financial::Threeds::Version2::Recurring

#threeds_v2_recurring_expiration_date, #threeds_v2_recurring_expiration_date=

Methods included from Mixins::Requests::Financial::Threeds::Version2::MerchantRisk

#threeds_v2_merchant_risk_pre_order_date, #threeds_v2_merchant_risk_pre_order_date=

Methods included from Mixins::Requests::Financial::Threeds::Version2::CardHolderAccount

#threeds_v2_card_holder_account_creation_date, #threeds_v2_card_holder_account_creation_date=, #threeds_v2_card_holder_account_last_change_date, #threeds_v2_card_holder_account_last_change_date=, #threeds_v2_card_holder_account_password_change_date, #threeds_v2_card_holder_account_password_change_date=, #threeds_v2_card_holder_account_registration_date, #threeds_v2_card_holder_account_registration_date=, #threeds_v2_card_holder_account_shipping_address_date_first_used, #threeds_v2_card_holder_account_shipping_address_date_first_used=

Methods included from Mixins::Requests::Financial::Cards::Recurring::ManagedRecurringAttributes

#managed_recurring_first_date, #managed_recurring_first_date=

Methods included from Mixins::Requests::Financial::Business::TravelAgenciesAttributes

#business_arrival_date, #business_arrival_date=, #business_departure_date, #business_departure_date=, #business_pick_up_date, #business_pick_up_date=, #business_return_date, #business_return_date=

Methods included from Mixins::Requests::Financial::Business::HotelsAndRealEstateRentalsAttributes

#business_check_in_date, #business_check_in_date=, #business_check_out_date, #business_check_out_date=

Methods included from Mixins::Requests::Financial::Business::FurnitureAttributes

#business_date_of_order, #business_date_of_order=, #business_delivery_date, #business_delivery_date=

Methods included from Mixins::Requests::Financial::Business::EventManagementAttributes

#business_event_end_date, #business_event_end_date=, #business_event_start_date, #business_event_start_date=

Methods included from Mixins::Requests::Financial::Business::CruiseLinesAttributes

#business_cruise_end_date, #business_cruise_end_date=, #business_cruise_start_date, #business_cruise_start_date=

Methods included from Mixins::Requests::Financial::Business::CarPlaneAndBoatRentalsAttributes

#business_vehicle_pick_up_date, #business_vehicle_pick_up_date=, #business_vehicle_return_date, #business_vehicle_return_date=

Methods included from Mixins::Requests::Financial::Business::AirlinesAirCarriersAttributes

#business_flight_arrival_date, #business_flight_arrival_date=, #business_flight_departure_date, #business_flight_departure_date=

Methods included from Mixins::Requests::Financial::Cards::UcofAttributes

#credential_on_file_settlement_date, #credential_on_file_settlement_date=

Methods included from Mixins::Requests::SmartRouterAttributes

#use_smart_router, #use_smart_router=

Methods inherited from GenesisRuby::Api::Request

#build_document, #initialize

Constructor Details

This class inherits a constructor from GenesisRuby::Api::Request