Class: GenesisRuby::Api::Requests::Financial::Cards::Payout

Overview

Payouts are credits without a reference transaction and as such are highly regulated and need specific gateway terminal configuration

Constant Summary

Constants included from Mixins::Requests::Financial::Cards::AccountOwnerAttributes

Mixins::Requests::Financial::Cards::AccountOwnerAttributes::ACCOUNT_NAME_LENGTH

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary

Attributes included from Mixins::Requests::Financial::SourceOfFundsAttributes

#source_of_funds

Attributes included from Mixins::Requests::Financial::PurposeOfPaymentAttributes

#purpose_of_payment

Attributes included from Mixins::Requests::Financial::MotoAttributes

#moto

Attributes included from Mixins::Requests::Financial::MoneyTransferPayoutAttributes

#money_transfer_purpose_of_payment, #money_transfer_receiver_account_number, #money_transfer_receiver_account_number_type, #money_transfer_receiver_address_city, #money_transfer_receiver_address_country, #money_transfer_receiver_address_line, #money_transfer_receiver_address_postal_code, #money_transfer_receiver_address_state, #money_transfer_receiver_first_name, #money_transfer_receiver_last_name, #money_transfer_sender_account_number, #money_transfer_sender_account_number_type, #money_transfer_sender_address_city, #money_transfer_sender_address_country, #money_transfer_sender_address_line, #money_transfer_sender_address_postal_code, #money_transfer_sender_address_state, #money_transfer_service_provider_name, #money_transfer_source_of_funds, #money_transfer_type

Attributes included from Mixins::Requests::Financial::GamingAttributes

#gaming

Attributes included from Mixins::Requests::Financial::DynamicDescriptorAttributes

#dynamic_descriptor_merchant_address, #dynamic_descriptor_merchant_city, #dynamic_descriptor_merchant_country, #dynamic_descriptor_merchant_geo_coordinates, #dynamic_descriptor_merchant_name, #dynamic_descriptor_merchant_phone, #dynamic_descriptor_merchant_service_city, #dynamic_descriptor_merchant_service_country, #dynamic_descriptor_merchant_service_geo_coordinates, #dynamic_descriptor_merchant_service_phone, #dynamic_descriptor_merchant_service_state, #dynamic_descriptor_merchant_service_zip_code, #dynamic_descriptor_merchant_state, #dynamic_descriptor_merchant_url, #dynamic_descriptor_merchant_zip_code, #dynamic_descriptor_sub_merchant_id

Attributes included from Mixins::Requests::Financial::CustomerIdentificationAttributes

#customer_identification_document_id, #customer_identification_issuing_country, #customer_identification_owner, #customer_identification_subtype, #customer_identification_type

Attributes included from Mixins::Requests::Financial::CryptoAttributes

#crypto

Attributes included from Mixins::Requests::Financial::Cards::FxRateAttributes

#fx_rate_id

Attributes included from Mixins::Requests::DocumentAttributes

#document_id

Attributes included from Mixins::Requests::DigitalAssetTypeAttributes

#digital_asset_type

Attributes included from Mixins::Requests::CustomerAddress::CustomerInfoAttributes

#customer_email, #customer_phone

Attributes included from Mixins::Requests::CustomerAddress::ShippingInfoAttributes

#shipping_address1, #shipping_address2, #shipping_city, #shipping_country, #shipping_first_name, #shipping_last_name, #shipping_neighborhood, #shipping_state, #shipping_zip_code

Attributes included from Mixins::Requests::CustomerAddress::BillingInfoAttributes

#billing_address1, #billing_address2, #billing_city, #billing_country, #billing_first_name, #billing_last_name, #billing_neighborhood, #billing_state, #billing_zip_code

Attributes inherited from Base::Financials::CreditCard

#scheme_tokenized

Attributes included from Mixins::Requests::Financial::Cards::UcofAttributes

#credential_on_file_transaction_identifier

Attributes included from Mixins::Requests::Financial::Cards::TokenizationParamsAttributes

#tokenization_eci, #tokenization_tavv

Attributes included from Mixins::Requests::Financial::Cards::TokenizationAttributes

#consumer_id, #remember_card, #token

Attributes included from Mixins::Requests::Financial::Cards::CreditCardAttributes

#card_holder, #card_number, #cvv, #expiration_month, #expiration_year

Attributes included from Mixins::Requests::Financial::Cards::CredentialOnFileAttributes

#credential_on_file

Attributes included from Mixins::Requests::Financial::Cards::AccountOwnerAttributes

#account_first_name, #account_last_name, #account_middle_name

Attributes included from Mixins::Requests::Financial::PaymentAttributes

#amount, #currency

Attributes included from Mixins::Requests::Financial::BaseAttributes

#remote_ip, #transaction_id, #usage

Attributes inherited from GenesisRuby::Api::Request

#api_config

Method Summary

Methods included from Mixins::Requests::Financial::MoneyTransferPayoutAttributes

#money_transfer_sender_birth_date, #money_transfer_sender_birth_date=

Methods included from Mixins::Requests::BirthDateAttributes

#birth_date, #birth_date=

Methods included from Mixins::Requests::Financial::Cards::UcofAttributes

#credential_on_file_settlement_date, #credential_on_file_settlement_date=

Methods included from Mixins::Requests::SmartRouterAttributes

#use_smart_router, #use_smart_router=

Methods inherited from GenesisRuby::Api::Request

#build_document, #initialize

Constructor Details

This class inherits a constructor from GenesisRuby::Api::Request