Class: GenesisRuby::Api::Requests::Financial::CashPayments::Pix

Overview

Pix is a payment service, which represents a new way of receiving/sending money. Pix allows payments to be made instantly.

Constant Summary

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary collapse

Attributes included from Mixins::Requests::Financial::PendingPaymentAttributes

#return_pending_url

Attributes included from Mixins::Requests::Financial::OnlineBankingPayments::PixAttributes

#company_activity, #company_type, #mothers_name

Attributes included from Mixins::Requests::Financial::BeneficiaryAttributes

#beneficiary_document_id, #beneficiary_name, #beneficiary_pix_key

Attributes included from Mixins::Requests::Financial::AsyncAttributes

#return_failure_url, #return_success_url

Attributes included from Mixins::Requests::DocumentAttributes

#document_id

Attributes included from Mixins::Requests::CustomerAddress::CustomerInfoAttributes

#customer_email, #customer_phone

Attributes included from Mixins::Requests::CustomerAddress::ShippingInfoAttributes

#shipping_address1, #shipping_address2, #shipping_city, #shipping_country, #shipping_first_name, #shipping_last_name, #shipping_neighborhood, #shipping_state, #shipping_zip_code

Attributes included from Mixins::Requests::CustomerAddress::BillingInfoAttributes

#billing_address1, #billing_address2, #billing_city, #billing_first_name, #billing_last_name, #billing_neighborhood, #billing_state, #billing_zip_code

Attributes included from Mixins::Requests::Financial::PaymentAttributes

#amount, #currency

Attributes included from Mixins::Requests::Financial::BaseAttributes

#remote_ip, #transaction_id, #usage

Attributes inherited from GenesisRuby::Api::Request

#api_config

Instance Method Summary collapse

Methods included from Mixins::Requests::Financial::OnlineBankingPayments::PixAttributes

#incorporation_date=

Methods included from Mixins::Requests::BirthDateAttributes

#birth_date, #birth_date=

Methods included from Mixins::Requests::SmartRouterAttributes

#use_smart_router, #use_smart_router=

Methods inherited from GenesisRuby::Api::Request

#build_document, #initialize

Constructor Details

This class inherits a constructor from GenesisRuby::Api::Request

Instance Attribute Details

#birth_cityObject

Returns the value of attribute birth_city.



24
25
26
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24

def birth_city
  @birth_city
end

#birth_stateObject

Returns the value of attribute birth_state.



24
25
26
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24

def birth_state
  @birth_state
end

#country_of_originObject

Returns the value of attribute country_of_origin.



24
25
26
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24

def country_of_origin
  @country_of_origin
end

#genderObject

Returns the value of attribute gender.



24
25
26
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24

def gender
  @gender
end

#marital_statusObject

Returns the value of attribute marital_status.



24
25
26
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24

def marital_status
  @marital_status
end

#nationalityObject

Returns the value of attribute nationality.



24
25
26
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24

def nationality
  @nationality
end

#sender_occupationObject

Returns the value of attribute sender_occupation.



24
25
26
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24

def sender_occupation
  @sender_occupation
end

Instance Method Details

#billing_countryObject

Billing Country custom accessor



28
29
30
31
32
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 28

def billing_country
  return nil unless @billing_country

  @billing_country.to_s.upcase
end

#incorporation_dateObject

Override incorpocation date with specific format for Pix request



35
36
37
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 35

def incorporation_date
  @incorporation_date&.strftime Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS
end