Class: GenesisRuby::Api::Requests::Financial::OnlineBankingPayments::InstaDebit::PayIn
- Inherits:
-
Base::Financial
- Object
- GenesisRuby::Api::Request
- Base::Financial
- GenesisRuby::Api::Requests::Financial::OnlineBankingPayments::InstaDebit::PayIn
- Includes:
- Mixins::Requests::AddressInfoAttributes, Mixins::Requests::Financial::CustomerAccountAttributes
- Defined in:
- lib/genesis_ruby/api/requests/financial/online_banking_payments/insta_debit/pay_in.rb
Overview
InstaDebit Payin transaction - after a successful validation of transaction parameters, transaction status is set to pending async and the consumer is redirected to the InstaDebit consumers page
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#return_url ⇒ Object
Returns the value of attribute return_url.
Attributes included from Mixins::Requests::Financial::CustomerAccountAttributes
Attributes included from Mixins::Requests::CustomerAddress::CustomerInfoAttributes
#customer_email, #customer_phone
Attributes included from Mixins::Requests::CustomerAddress::ShippingInfoAttributes
#shipping_address1, #shipping_address2, #shipping_city, #shipping_country, #shipping_first_name, #shipping_last_name, #shipping_neighborhood, #shipping_state, #shipping_zip_code
Attributes included from Mixins::Requests::CustomerAddress::BillingInfoAttributes
#billing_address1, #billing_address2, #billing_city, #billing_country, #billing_first_name, #billing_last_name, #billing_neighborhood, #billing_state, #billing_zip_code
Attributes included from Mixins::Requests::Financial::PaymentAttributes
Attributes included from Mixins::Requests::Financial::BaseAttributes
#remote_ip, #transaction_id, #usage
Attributes inherited from GenesisRuby::Api::Request
Method Summary
Methods included from Mixins::Requests::SmartRouterAttributes
#use_smart_router, #use_smart_router=
Methods inherited from GenesisRuby::Api::Request
Constructor Details
This class inherits a constructor from GenesisRuby::Api::Request
Instance Attribute Details
#return_url ⇒ Object
Returns the value of attribute return_url.
17 18 19 |
# File 'lib/genesis_ruby/api/requests/financial/online_banking_payments/insta_debit/pay_in.rb', line 17 def return_url @return_url end |