Class: GenesisRuby::Api::Requests::Financial::OnlineBankingPayments::Wechat

Inherits:
Base::Financial show all
Includes:
Mixins::Requests::AddressInfoAttributes, Mixins::Requests::Financial::AsyncAttributes
Defined in:
lib/genesis_ruby/api/requests/financial/online_banking_payments/wechat.rb

Overview

WeChat Pay solution offers merchants access to the over 300 million WeChat users that have linked payment accounts to their WeChat account

Constant Summary

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary collapse

Attributes included from Mixins::Requests::Financial::AsyncAttributes

#return_failure_url, #return_success_url

Attributes included from Mixins::Requests::CustomerAddress::CustomerInfoAttributes

#customer_email, #customer_phone

Attributes included from Mixins::Requests::CustomerAddress::ShippingInfoAttributes

#shipping_address1, #shipping_address2, #shipping_city, #shipping_country, #shipping_first_name, #shipping_last_name, #shipping_neighborhood, #shipping_state, #shipping_zip_code

Attributes included from Mixins::Requests::CustomerAddress::BillingInfoAttributes

#billing_address1, #billing_address2, #billing_city, #billing_country, #billing_first_name, #billing_last_name, #billing_neighborhood, #billing_state, #billing_zip_code

Attributes included from Mixins::Requests::Financial::PaymentAttributes

#amount, #currency

Attributes included from Mixins::Requests::Financial::BaseAttributes

#remote_ip, #transaction_id, #usage

Attributes inherited from GenesisRuby::Api::Request

#api_config

Method Summary

Methods included from Mixins::Requests::SmartRouterAttributes

#use_smart_router, #use_smart_router=

Methods inherited from GenesisRuby::Api::Request

#build_document, #initialize

Constructor Details

This class inherits a constructor from GenesisRuby::Api::Request

Instance Attribute Details

#product_codeObject

Returns the value of attribute product_code.



15
16
17
# File 'lib/genesis_ruby/api/requests/financial/online_banking_payments/wechat.rb', line 15

def product_code
  @product_code
end

#product_descObject

Returns the value of attribute product_desc.



15
16
17
# File 'lib/genesis_ruby/api/requests/financial/online_banking_payments/wechat.rb', line 15

def product_desc
  @product_desc
end

#product_numObject

Returns the value of attribute product_num.



15
16
17
# File 'lib/genesis_ruby/api/requests/financial/online_banking_payments/wechat.rb', line 15

def product_num
  @product_num
end