Class: GenesisRuby::Api::Requests::NonFinancial::Fraud::Chargeback::DateRange
- Inherits:
-
GenesisRuby::Api::Request
- Object
- GenesisRuby::Api::Request
- GenesisRuby::Api::Requests::NonFinancial::Fraud::Chargeback::DateRange
- Includes:
- Mixins::Requests::NonFinancial::DateAttributes, Mixins::Requests::NonFinancial::PagingAttributes
- Defined in:
- lib/genesis_ruby/api/requests/non_financial/fraud/chargeback/date_range.rb
Overview
Date range based chargeback retrieval allows you to fetch information for all chargebacks for a given merchant within a given date range
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#externally_processed ⇒ Object
Returns the value of attribute externally_processed.
-
#processing_type ⇒ Object
Returns the value of attribute processing_type.
Attributes included from Mixins::Requests::NonFinancial::PagingAttributes
Attributes inherited from GenesisRuby::Api::Request
Instance Method Summary collapse
-
#end_date ⇒ Object
End of the requested date range.
-
#import_date ⇒ Object
Date of import in the system.
-
#import_date=(value) ⇒ Object
Date of import in the system.
-
#start_date ⇒ Object
Start of the requested date range.
Methods included from Mixins::Requests::NonFinancial::DateAttributes
#end_date=, #end_date_from, #end_date_from=, #end_date_to, #end_date_to=, #start_date=, #start_date_from, #start_date_from=, #start_date_to, #start_date_to=
Methods inherited from GenesisRuby::Api::Request
Constructor Details
This class inherits a constructor from GenesisRuby::Api::Request
Instance Attribute Details
#externally_processed ⇒ Object
Returns the value of attribute externally_processed.
19 20 21 |
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/chargeback/date_range.rb', line 19 def externally_processed @externally_processed end |
#processing_type ⇒ Object
Returns the value of attribute processing_type.
19 20 21 |
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/chargeback/date_range.rb', line 19 def processing_type @processing_type end |
Instance Method Details
#end_date ⇒ Object
End of the requested date range
27 28 29 |
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/chargeback/date_range.rb', line 27 def end_date @end_date&.strftime Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 end |
#import_date ⇒ Object
Date of import in the system
32 33 34 |
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/chargeback/date_range.rb', line 32 def import_date @import_date&.strftime Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 end |
#import_date=(value) ⇒ Object
Date of import in the system
37 38 39 |
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/chargeback/date_range.rb', line 37 def import_date=(value) parse_date attribute: __method__, value: value, allow_empty: true end |
#start_date ⇒ Object
Start of the requested date range
22 23 24 |
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/chargeback/date_range.rb', line 22 def start_date @start_date&.strftime Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 end |