Class: GenesisRuby::Api::Requests::NonFinancial::Fraud::Reports::DateRange

Inherits:
GenesisRuby::Api::Request show all
Includes:
Mixins::Requests::NonFinancial::DateAttributes, Mixins::Requests::NonFinancial::PagingAttributes
Defined in:
lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb

Overview

Date range based SAFE/TC40 retrieval allows you to fetch information for all SAFE/TC40 reports for a given merchant within a given date range

Constant Summary

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary

Attributes included from Mixins::Requests::NonFinancial::PagingAttributes

#page, #per_page

Attributes inherited from GenesisRuby::Api::Request

#api_config

Instance Method Summary collapse

Methods included from Mixins::Requests::NonFinancial::DateAttributes

#end_date=, #end_date_from, #end_date_from=, #end_date_to, #end_date_to=, #start_date=, #start_date_from, #start_date_from=, #start_date_to, #start_date_to=

Methods inherited from GenesisRuby::Api::Request

#build_document, #initialize

Constructor Details

This class inherits a constructor from GenesisRuby::Api::Request

Instance Method Details

#end_dateObject

End of the requested date range



22
23
24
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb', line 22

def end_date
  @end_date&.strftime Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601
end

#import_dateObject

Date of import in the system



27
28
29
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb', line 27

def import_date
  @import_date&.strftime Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601
end

#import_date=(value) ⇒ Object

Date of import in the system



32
33
34
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb', line 32

def import_date=(value)
  parse_date attribute: __method__, value: value, allow_empty: true
end

#report_end_dateObject

End of the requested date range for the date when the fraud was reported



47
48
49
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb', line 47

def report_end_date
  @report_end_date&.strftime Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601
end

#report_end_date=(value) ⇒ Object

End of the requested date range for the date when the fraud was reported



52
53
54
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb', line 52

def report_end_date=(value)
  parse_date attribute: __method__, value: value, allow_empty: true
end

#report_start_dateObject

Start of the requested date range for the date when the fraud was reported



37
38
39
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb', line 37

def report_start_date
  @report_start_date&.strftime Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601
end

#report_start_date=(value) ⇒ Object

Start of the requested date range for the date when the fraud was reported



42
43
44
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb', line 42

def report_start_date=(value)
  parse_date attribute: __method__, value: value, allow_empty: true
end

#start_dateObject

Start of the requested date range



17
18
19
# File 'lib/genesis_ruby/api/requests/non_financial/fraud/reports/date_range.rb', line 17

def start_date
  @start_date&.strftime Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601
end