Class: GenesisRuby::Api::Requests::NonFinancial::Kyc::Call::Update
- Inherits:
-
Base::NonFinancial::Kyc::Base
- Object
- GenesisRuby::Api::Request
- Base::Versioned
- Base::NonFinancial::Kyc::Base
- GenesisRuby::Api::Requests::NonFinancial::Kyc::Call::Update
- Defined in:
- lib/genesis_ruby/api/requests/non_financial/kyc/call/update.rb
Overview
Update Call Request class for KYC Non-Financial API services This method is used to update the call status with the latest info received from the main system. It also updates the transaction associated with this verification call.
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#reference_id ⇒ Object
Returns the value of attribute reference_id.
-
#security_code_input ⇒ Object
Returns the value of attribute security_code_input.
- #verification_status ⇒ Object
Attributes inherited from Base::Versioned
Attributes inherited from GenesisRuby::Api::Request
Instance Method Summary collapse
-
#initialize(configuration, _builder_interface = nil) ⇒ Update
constructor
Initialize the Update Call document request.
Methods inherited from Base::NonFinancial::Kyc::Base
Methods inherited from GenesisRuby::Api::Request
Constructor Details
#initialize(configuration, _builder_interface = nil) ⇒ Update
Initialize the Update Call document request
20 21 22 23 24 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/call/update.rb', line 20 def initialize(configuration, _builder_interface = nil) super configuration self.request_path = 'update_authentication' end |
Instance Attribute Details
#reference_id ⇒ Object
Returns the value of attribute reference_id.
16 17 18 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/call/update.rb', line 16 def reference_id @reference_id end |
#security_code_input ⇒ Object
Returns the value of attribute security_code_input.
16 17 18 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/call/update.rb', line 16 def security_code_input @security_code_input end |
#verification_status ⇒ Object
26 27 28 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/call/update.rb', line 26 def verification_status @verification_status.to_s end |