Class: GenesisRuby::Api::Requests::NonFinancial::Kyc::Transaction::Create
- Inherits:
-
Base::NonFinancial::Kyc::Base
- Object
- GenesisRuby::Api::Request
- Base::Versioned
- Base::NonFinancial::Kyc::Base
- GenesisRuby::Api::Requests::NonFinancial::Kyc::Transaction::Create
- Includes:
- Mixins::Requests::Financial::PaymentAttributes, Mixins::Requests::NonFinancial::Kyc::CustomerInformationAttributes, Mixins::Requests::NonFinancial::Kyc::DepositLimitsAttributes, Mixins::Requests::NonFinancial::Kyc::KycBillingInfoAttributes, Mixins::Requests::NonFinancial::Kyc::KycShippingInfoAttributes, Mixins::Requests::NonFinancial::Kyc::PaymentDetailsAttributes
- Defined in:
- lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb
Overview
Create transaction type for KYC Non-Financial API services
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#current_balance ⇒ Object
Returns the current balance as an integer.
-
#custom_variable ⇒ Object
Returns the value of attribute custom_variable.
-
#customer_device_id ⇒ Object
Returns the value of attribute customer_device_id.
-
#customer_ip_address ⇒ Object
Returns the value of attribute customer_ip_address.
-
#customer_loyalty_level ⇒ Object
Returns the value of attribute customer_loyalty_level.
-
#customer_password ⇒ Object
Returns the value of attribute customer_password.
-
#customer_registration_device_id ⇒ Object
Returns the value of attribute customer_registration_device_id.
-
#customer_registration_ip_address ⇒ Object
Returns the value of attribute customer_registration_ip_address.
-
#customer_status ⇒ Object
Returns the value of attribute customer_status.
-
#customer_unique_id ⇒ Object
Returns the value of attribute customer_unique_id.
-
#customer_username ⇒ Object
Returns the value of attribute customer_username.
-
#deposits_count ⇒ Object
Returns the deposits count as an integer.
-
#device_fingerprint ⇒ Object
Returns the value of attribute device_fingerprint.
-
#device_fingerprint_type ⇒ Object
Returns the value of attribute device_fingerprint_type.
-
#industry_type ⇒ Object
Returns the value of attribute industry_type.
-
#merchant_website ⇒ Object
Returns the value of attribute merchant_website.
-
#order_source ⇒ Object
Returns the value of attribute order_source.
-
#rule_context ⇒ Object
Returns the rule context as an integer.
-
#session_id ⇒ Object
Returns the value of attribute session_id.
-
#shopping_cart_items_count ⇒ Object
Returns the value of attribute shopping_cart_items_count.
-
#third_party_device_id ⇒ Object
Returns the value of attribute third_party_device_id.
-
#transaction_status ⇒ Object
Returns the value of attribute transaction_status.
-
#transaction_unique_id ⇒ Object
Returns the value of attribute transaction_unique_id.
-
#withdrawals_count ⇒ Object
Returns the withdrawals count as an integer.
Attributes included from Mixins::Requests::NonFinancial::Kyc::PaymentDetailsAttributes
#account, #bin, #cvv_present, #ewallet_id, #hashed_pan, #routing, #tail
Attributes included from Mixins::Requests::NonFinancial::Kyc::KycShippingInfoAttributes
#shipping_address1, #shipping_address2, #shipping_city, #shipping_country, #shipping_customer_email, #shipping_first_name, #shipping_last_name, #shipping_phone1, #shipping_province, #shipping_zip_code
Attributes included from Mixins::Requests::NonFinancial::Kyc::KycBillingInfoAttributes
#billing_address1, #billing_address2, #billing_birth_date, #billing_city, #billing_country, #billing_customer_email, #billing_first_name, #billing_gender, #billing_last_name, #billing_phone1, #billing_province, #billing_zip_code
Attributes included from Mixins::Requests::NonFinancial::Kyc::CustomerInformationAttributes
#address1, #address2, #city, #country, #customer_email, #document_number, #document_type, #first_name, #gender, #last_name, #middle_name, #phone1, #phone2, #province, #zip_code
Attributes included from Mixins::Requests::NonFinancial::Kyc::DepositLimitsAttributes
#daily_maximum, #minimum, #monthly_maximum, #payment_method, #weekly_maximum
Attributes included from Mixins::Requests::Financial::PaymentAttributes
Attributes inherited from Base::Versioned
Attributes inherited from GenesisRuby::Api::Request
Instance Method Summary collapse
-
#customer_registration_date ⇒ Object
Returns customer registration date.
-
#customer_registration_date=(value) ⇒ Object
Sets customer registration date.
-
#first_deposit_date ⇒ Object
Returns the first deposit date.
-
#first_deposit_date=(value) ⇒ Object
Sets the first deposit date.
-
#first_withdrawal_date ⇒ Object
Returns the first withdrawal date.
-
#first_withdrawal_date=(value) ⇒ Object
Sets the first withdrawal date.
-
#initialize(configuration, _builder_interface = nil) ⇒ Create
constructor
Initializes the Create Transaction Request.
-
#local_time ⇒ Object
Returns the local time in the format YYYY-MM-DD HH:MM:SS.
-
#local_time=(value) ⇒ Object
Sets the local time.
-
#transaction_created_at ⇒ Object
Returns the transaction created at date in the format YYYY-MM-DD HH:MM:SS.
-
#transaction_created_at=(value) ⇒ Object
Sets the transaction created at date.
Methods included from Mixins::Requests::NonFinancial::Kyc::PaymentDetailsAttributes
Methods included from Mixins::Requests::NonFinancial::Kyc::KycShippingInfoAttributes
Methods included from Mixins::Requests::BirthDateAttributes
Methods inherited from Base::NonFinancial::Kyc::Base
Methods inherited from GenesisRuby::Api::Request
Constructor Details
#initialize(configuration, _builder_interface = nil) ⇒ Create
Initializes the Create Transaction Request
34 35 36 37 38 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 34 def initialize(configuration, _builder_interface = nil) super configuration self.request_path = 'create_transaction' end |
Instance Attribute Details
#current_balance ⇒ Object
Returns the current balance as an integer
101 102 103 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 101 def current_balance @current_balance&.to_i end |
#custom_variable ⇒ Object
Returns the value of attribute custom_variable.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def custom_variable @custom_variable end |
#customer_device_id ⇒ Object
Returns the value of attribute customer_device_id.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_device_id @customer_device_id end |
#customer_ip_address ⇒ Object
Returns the value of attribute customer_ip_address.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_ip_address @customer_ip_address end |
#customer_loyalty_level ⇒ Object
Returns the value of attribute customer_loyalty_level.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_loyalty_level @customer_loyalty_level end |
#customer_password ⇒ Object
Returns the value of attribute customer_password.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_password @customer_password end |
#customer_registration_device_id ⇒ Object
Returns the value of attribute customer_registration_device_id.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_registration_device_id @customer_registration_device_id end |
#customer_registration_ip_address ⇒ Object
Returns the value of attribute customer_registration_ip_address.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_registration_ip_address @customer_registration_ip_address end |
#customer_status ⇒ Object
Returns the value of attribute customer_status.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_status @customer_status end |
#customer_unique_id ⇒ Object
Returns the value of attribute customer_unique_id.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_unique_id @customer_unique_id end |
#customer_username ⇒ Object
Returns the value of attribute customer_username.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def customer_username @customer_username end |
#deposits_count ⇒ Object
Returns the deposits count as an integer
91 92 93 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 91 def deposits_count @deposits_count&.to_i end |
#device_fingerprint ⇒ Object
Returns the value of attribute device_fingerprint.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def device_fingerprint @device_fingerprint end |
#device_fingerprint_type ⇒ Object
Returns the value of attribute device_fingerprint_type.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def device_fingerprint_type @device_fingerprint_type end |
#industry_type ⇒ Object
Returns the value of attribute industry_type.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def industry_type @industry_type end |
#merchant_website ⇒ Object
Returns the value of attribute merchant_website.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def merchant_website @merchant_website end |
#order_source ⇒ Object
Returns the value of attribute order_source.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def order_source @order_source end |
#rule_context ⇒ Object
Returns the rule context as an integer
106 107 108 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 106 def rule_context @rule_context&.to_i end |
#session_id ⇒ Object
Returns the value of attribute session_id.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def session_id @session_id end |
#shopping_cart_items_count ⇒ Object
Returns the value of attribute shopping_cart_items_count.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def shopping_cart_items_count @shopping_cart_items_count end |
#third_party_device_id ⇒ Object
Returns the value of attribute third_party_device_id.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def third_party_device_id @third_party_device_id end |
#transaction_status ⇒ Object
Returns the value of attribute transaction_status.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def transaction_status @transaction_status end |
#transaction_unique_id ⇒ Object
Returns the value of attribute transaction_unique_id.
23 24 25 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 23 def transaction_unique_id @transaction_unique_id end |
#withdrawals_count ⇒ Object
Returns the withdrawals count as an integer
96 97 98 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 96 def withdrawals_count @withdrawals_count&.to_i end |
Instance Method Details
#customer_registration_date ⇒ Object
Returns customer registration date
41 42 43 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 41 def customer_registration_date @customer_registration_date&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 end |
#customer_registration_date=(value) ⇒ Object
Sets customer registration date
46 47 48 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 46 def customer_registration_date=(value) parse_date attribute: __method__, value: value, allow_empty: true end |
#first_deposit_date ⇒ Object
Returns the first deposit date
51 52 53 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 51 def first_deposit_date @first_deposit_date&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 end |
#first_deposit_date=(value) ⇒ Object
Sets the first deposit date
56 57 58 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 56 def first_deposit_date=(value) parse_date attribute: __method__, value: value, allow_empty: true end |
#first_withdrawal_date ⇒ Object
Returns the first withdrawal date
61 62 63 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 61 def first_withdrawal_date @first_withdrawal_date&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 end |
#first_withdrawal_date=(value) ⇒ Object
Sets the first withdrawal date
66 67 68 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 66 def first_withdrawal_date=(value) parse_date attribute: __method__, value: value, allow_empty: true end |
#local_time ⇒ Object
Returns the local time in the format YYYY-MM-DD HH:MM:SS
71 72 73 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 71 def local_time @local_time&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_H_I_S end |
#local_time=(value) ⇒ Object
Sets the local time
76 77 78 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 76 def local_time=(value) parse_date attribute: __method__, value: value, allow_empty: true end |
#transaction_created_at ⇒ Object
Returns the transaction created at date in the format YYYY-MM-DD HH:MM:SS
81 82 83 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 81 def transaction_created_at @transaction_created_at&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_H_I_S end |
#transaction_created_at=(value) ⇒ Object
Sets the transaction created at date
86 87 88 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/transaction/create.rb', line 86 def transaction_created_at=(value) parse_date attribute: __method__, value: value, allow_empty: true end |