Class: GenesisRuby::Api::Requests::NonFinancial::Kyc::Verifications::Create

Overview

The verification request will provide a link that will be used to redirect the customer. The customer will provide the required documents and will be verified against them. As a result, the user will be redirected back to merchant based on the provided redirect URL.

Constant Summary

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary collapse

Attributes included from Mixins::Requests::NonFinancial::Kyc::BusinessAttributes

#business_name

Attributes included from Mixins::Requests::NonFinancial::Kyc::VerificationDocumentAttributes

#document_allow_offline, #document_allow_online, #document_first_name, #document_last_name

Attributes included from Mixins::Requests::NonFinancial::Kyc::VerificationAttributes

#backside_proof_required, #country, #email, #reference_id

Attributes included from Mixins::Requests::NonFinancial::Kyc::FaceAttributes

#face_allow_offline, #face_allow_online, #face_check_duplicate_request

Attributes included from Mixins::Requests::NonFinancial::Kyc::BackgroundChecksAttributes

#background_checks_async_update, #background_checks_first_name, #background_checks_full_name, #background_checks_last_name, #background_checks_match_score, #background_checks_middle_name

Attributes inherited from Base::Versioned

#allowed_versions, #version

Attributes inherited from GenesisRuby::Api::Request

#api_config

Instance Method Summary collapse

Methods included from Mixins::Requests::NonFinancial::Kyc::BusinessAttributes

#business_incorporation_date, #business_incorporation_date=

Methods included from Mixins::Requests::NonFinancial::Kyc::VerificationDocumentAttributes

#document_date_of_birth, #document_date_of_birth=

Methods included from Mixins::Requests::NonFinancial::Kyc::VerificationAttributes

#document_supported_types, #document_supported_types=, #expiry_date, #expiry_date=

Methods included from Mixins::Requests::NonFinancial::Kyc::BackgroundChecksAttributes

#background_checks_date_of_birth, #background_checks_date_of_birth=, #background_checks_filters, #background_checks_filters=

Methods inherited from Base::NonFinancial::Kyc::Base

#init_configuration

Methods inherited from GenesisRuby::Api::Request

#build_document

Constructor Details

#initialize(configuration, _builder_interface = nil) ⇒ Create

Initializes the Create Verification Request



29
30
31
32
33
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/create.rb', line 29

def initialize(configuration, _builder_interface = nil)
  super configuration

  self.request_path = 'verifications'
end

Instance Attribute Details

#address_backside_proof_requiredObject

Returns the value of attribute address_backside_proof_required.



25
26
27
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/create.rb', line 25

def address_backside_proof_required
  @address_backside_proof_required
end

#address_supported_typesObject

Returns the value of attribute address_supported_types.



26
27
28
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/create.rb', line 26

def address_supported_types
  @address_supported_types
end

#allow_retryObject

Returns the value of attribute allow_retry.



25
26
27
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/create.rb', line 25

def allow_retry
  @allow_retry
end

#languageObject

Returns the value of attribute language.



25
26
27
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/create.rb', line 25

def language
  @language
end

#redirect_urlObject

Returns the value of attribute redirect_url.



26
27
28
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/create.rb', line 26

def redirect_url
  @redirect_url
end

#verification_modeObject

Returns the value of attribute verification_mode.



25
26
27
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/create.rb', line 25

def verification_mode
  @verification_mode
end