Class: GenesisRuby::Api::Requests::NonFinancial::Kyc::Verifications::Status

Inherits:
Base::NonFinancial::Kyc::Base show all
Includes:
Mixins::Requests::Financial::ReferenceAttributes
Defined in:
lib/genesis_ruby/api/requests/non_financial/kyc/verifications/status.rb

Overview

Verification status check request can be performed by reference_id. A status check may be needed if async notification has not arrived yet or when kyc notifications are not used in general.

Constant Summary

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary

Attributes included from Mixins::Requests::Financial::ReferenceAttributes

#reference_id

Attributes inherited from Base::Versioned

#allowed_versions, #version

Attributes inherited from GenesisRuby::Api::Request

#api_config

Instance Method Summary collapse

Methods inherited from Base::NonFinancial::Kyc::Base

#init_configuration

Methods inherited from GenesisRuby::Api::Request

#build_document

Constructor Details

#initialize(configuration, _builder_interface = nil) ⇒ Status

Initialize the request



16
17
18
19
20
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/status.rb', line 16

def initialize(configuration, _builder_interface = nil)
  super configuration

  self.request_path = 'verifications/status'
end