Class: GenesisRuby::Api::Requests::NonFinancial::ProcessedTransactions::DateRange
- Inherits:
-
GenesisRuby::Api::Request
- Object
- GenesisRuby::Api::Request
- GenesisRuby::Api::Requests::NonFinancial::ProcessedTransactions::DateRange
- Includes:
- Mixins::Requests::NonFinancial::DateAttributes, Mixins::Requests::NonFinancial::PagingAttributes
- Defined in:
- lib/genesis_ruby/api/requests/non_financial/processed_transactions/date_range.rb
Overview
Date range based processed transaction retrieval allows you to fetch information for all processed transactions for a given merchant within a given date range.
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#externally_processed ⇒ Object
Returns the value of attribute externally_processed.
-
#processing_type ⇒ Object
Returns the value of attribute processing_type.
Attributes included from Mixins::Requests::NonFinancial::PagingAttributes
Attributes inherited from GenesisRuby::Api::Request
Instance Method Summary collapse
-
#end_date ⇒ Object
End of the requested date range.
-
#start_date ⇒ Object
Start of the requested date range.
Methods included from Mixins::Requests::NonFinancial::DateAttributes
Methods inherited from GenesisRuby::Api::Request
Constructor Details
This class inherits a constructor from GenesisRuby::Api::Request
Instance Attribute Details
#externally_processed ⇒ Object
Returns the value of attribute externally_processed.
18 19 20 |
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/date_range.rb', line 18 def externally_processed @externally_processed end |
#processing_type ⇒ Object
Returns the value of attribute processing_type.
18 19 20 |
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/date_range.rb', line 18 def processing_type @processing_type end |
Instance Method Details
#end_date ⇒ Object
End of the requested date range
26 27 28 |
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/date_range.rb', line 26 def end_date @end_date&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 end |
#start_date ⇒ Object
Start of the requested date range
21 22 23 |
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/date_range.rb', line 21 def start_date @start_date&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601 end |