Class: GenesisRuby::Api::Requests::NonFinancial::ProcessedTransactions::PostDateRange

Inherits:
GenesisRuby::Api::Request show all
Includes:
Mixins::Requests::NonFinancial::DateAttributes, Mixins::Requests::NonFinancial::PagingAttributes
Defined in:
lib/genesis_ruby/api/requests/non_financial/processed_transactions/post_date_range.rb

Overview

Post Date range based processed transaction retrieval allows you to fetch information for all processed transactions for a given merchant within a given post date range.

Constant Summary

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary collapse

Attributes included from Mixins::Requests::NonFinancial::PagingAttributes

#page, #per_page

Attributes inherited from GenesisRuby::Api::Request

#api_config

Instance Method Summary collapse

Methods included from Mixins::Requests::NonFinancial::DateAttributes

#end_date=, #start_date=

Methods inherited from GenesisRuby::Api::Request

#build_document, #initialize

Constructor Details

This class inherits a constructor from GenesisRuby::Api::Request

Instance Attribute Details

#batch_numberObject

Returns the value of attribute batch_number.



18
19
20
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/post_date_range.rb', line 18

def batch_number
  @batch_number
end

#batch_slip_numberObject

Returns the value of attribute batch_slip_number.



18
19
20
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/post_date_range.rb', line 18

def batch_slip_number
  @batch_slip_number
end

#deposit_slip_numberObject

Returns the value of attribute deposit_slip_number.



18
19
20
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/post_date_range.rb', line 18

def deposit_slip_number
  @deposit_slip_number
end

#externally_processedObject

Returns the value of attribute externally_processed.



18
19
20
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/post_date_range.rb', line 18

def externally_processed
  @externally_processed
end

#processing_typeObject

Returns the value of attribute processing_type.



18
19
20
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/post_date_range.rb', line 18

def processing_type
  @processing_type
end

Instance Method Details

#end_dateObject

End of the requested date range



27
28
29
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/post_date_range.rb', line 27

def end_date
  @end_date&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601
end

#start_dateObject

Start of the requested date range



22
23
24
# File 'lib/genesis_ruby/api/requests/non_financial/processed_transactions/post_date_range.rb', line 22

def start_date
  @start_date&.strftime GenesisRuby::Api::Constants::DateTimeFormats::YYYY_MM_DD_ISO_8601
end