Class: GenesisRuby::Api::Requests::NonFinancial::Reconcile::DateRange

Inherits:
GenesisRuby::Api::Request show all
Includes:
Mixins::Requests::NonFinancial::DateAttributes
Defined in:
lib/genesis_ruby/api/requests/non_financial/reconcile/date_range.rb

Overview

Date range based reconciliation allows you to fetch information for all payment transactions from a terminal within a given date range. The response is paginated, each request will return 100 entries max.

Constant Summary

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary collapse

Attributes inherited from GenesisRuby::Api::Request

#api_config

Method Summary

Methods included from Mixins::Requests::NonFinancial::DateAttributes

#end_date, #end_date=, #end_date_from, #end_date_from=, #end_date_to, #end_date_to=, #start_date, #start_date=, #start_date_from, #start_date_from=, #start_date_to, #start_date_to=

Methods inherited from GenesisRuby::Api::Request

#build_document, #initialize

Constructor Details

This class inherits a constructor from GenesisRuby::Api::Request

Instance Attribute Details

#pageObject

Returns the value of attribute page.



15
16
17
# File 'lib/genesis_ruby/api/requests/non_financial/reconcile/date_range.rb', line 15

def page
  @page
end