Class: GenesisRuby::Api::Requests::Wpf::Reconcile

Inherits:
GenesisRuby::Api::Request show all
Defined in:
lib/genesis_ruby/api/requests/wpf/reconcile.rb

Overview

Reconcile can be used to retrieve data about a payment. This can be useful if you want to retrieve information about a payment whose status is timeout, which returned an error or has changed eg. has beed chargebacked.

Constant Summary

Constants inherited from GenesisRuby::Api::Request

GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS

Instance Attribute Summary collapse

Attributes inherited from GenesisRuby::Api::Request

#api_config

Method Summary

Methods inherited from GenesisRuby::Api::Request

#build_document, #initialize

Constructor Details

This class inherits a constructor from GenesisRuby::Api::Request

Instance Attribute Details

#unique_idObject

Returns the value of attribute unique_id.



12
13
14
# File 'lib/genesis_ruby/api/requests/wpf/reconcile.rb', line 12

def unique_id
  @unique_id
end