Module: GenesisRuby::Api::Constants::States
- Extended by:
- Mixins::Constants::Common
- Defined in:
- lib/genesis_ruby/api/constants/states.rb,
lib/genesis_ruby/api/constants/states/state.rb
Overview
Genesis Response States
Defined Under Namespace
Classes: State
Constant Summary collapse
- APPROVED =
Transaction was approved by the schemes and is successful.
'approved'- DECLINED =
Transaction was declined by the schemes or risk management.
'declined'- PENDING =
The outcome of the transaction could not be determined, e.g. at a timeout situation. Transaction state will eventually change, so make a reconcile after a certain time frame.
'pending'- PENDING_ASYNC =
An asynchronous transaction (3-D secure payment) has been initiated and is waiting for user input. Updates of this state will be sent to the notification url specified in request.
'pending_async'- IN_PROGRESS =
Transaction is in-progress
'in_progress'- REFUNDED =
Once an approved transaction is refunded the state changes to refunded.
'refunded'- VOIDED =
Transaction was authorized, but later the merchant canceled it.
'voided'- ERROR =
An error has occurred while negotiating with the schemes.
'error'- UNSUCCESSFUL =
Transaction failed, but it was not declined
'unsuccessful'- NEW =
WPF initial status
'new'- USER =
WPF in-progress status
'user'- TIMEOUT =
WPF timeout has occurred
'timeout'- CHARGEBACKED =
Once an approved transaction is chargeback the state changes to change- backed.
Chargeback is the state of rejecting an accepted transaction (with funds transferred) by the cardholder or the issuer
'chargebacked'- CHARGEBACK_REVERSED =
Once a chargebacked transaction is charged, the state changes to charge- back reversed.
Chargeback has been canceled.
'chargeback_reversed'- PRE_ARBITRATED =
Once a chargeback reversed transaction is chargebacked the state changes to pre arbitrated.
'pre_arbitrated'- ENABLED =
Status of the consumer from Consumer API
'enabled'- DISABLED =
Status of the consumer from Consumer API
'disabled'- SUCCESS =
Transaction API success status
'success'- SUBMITTED =
WPF status represent submitted form
'submitted'- PENDING_HOLD =
An asynchronous transaction has been finalized by user but is waiting final update from provider.
'pending_hold'- SECOND_CHARGEBACKED =
Once a chargeback_reversed/represented transaction is chargebacked the state changes to second chargebacked.
'second_chargebacked'- REPRESENTED =
Once a chargebacked transaction is charged, the state changes to represented. Chargeback has been canceled.
'represented'