Class: GenesisRuby::Api::Constants::Transactions::Parameters::CredentialOnFiles
- Inherits:
-
Object
- Object
- GenesisRuby::Api::Constants::Transactions::Parameters::CredentialOnFiles
- Extended by:
- Mixins::Constants::Common
- Defined in:
- lib/genesis_ruby/api/constants/transactions/parameters/credential_on_files.rb
Overview
Credential On Files allowed values
Constant Summary collapse
- INITIAL_CUSTOMER_INITIATED =
Initial transaction used to store payment credentials for future customer initiated payments while processing. Required for external tokenization, and optional for gateway-based tokenization
'initial_customer_initiated'- SUBSEQUENT_CUSTOMER_INITIATED =
Subsequent customer initiated transaction using previously stored payment credentials. Required for external tokenization, and optional for gateway-based tokenization
'subsequent_customer_initiated'- MERCHANT_UNSCHEDULED =
For UCOF transaction, the scheme transaction identifier of the initial transaction must be sent in the transaction request. For MasterCard or Maestro UCOF, the scheme settlement date in MMDD format (e.g. 0107) of the initial transaction must be sent in the transaction request.
'merchant_unscheduled'