Module: GenesisRuby::Api::Mixins::Requests::Financial::Business::CarPlaneAndBoatRentalsAttributes
- Included in:
- BusinessAttributes
- Defined in:
- lib/genesis_ruby/api/mixins/requests/financial/business/car_plane_and_boat_rentals_attributes.rb
Overview
Mixin Car Plane and Boat Rentals Attributes
Instance Attribute Summary collapse
-
#business_supplier_name ⇒ Object
Returns the value of attribute business_supplier_name.
Instance Method Summary collapse
-
#business_vehicle_pick_up_date ⇒ Object
The date when customer takes the vehicle.
-
#business_vehicle_pick_up_date=(value) ⇒ Object
The date when customer takes the vehicle.
-
#business_vehicle_return_date ⇒ Object
The date when the customer returns the vehicle back.
-
#business_vehicle_return_date=(value) ⇒ Object
The date when the customer returns the vehicle back.
Instance Attribute Details
#business_supplier_name ⇒ Object
Returns the value of attribute business_supplier_name.
12 13 14 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/business/car_plane_and_boat_rentals_attributes.rb', line 12 def business_supplier_name @business_supplier_name end |
Instance Method Details
#business_vehicle_pick_up_date ⇒ Object
The date when customer takes the vehicle
15 16 17 18 19 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/business/car_plane_and_boat_rentals_attributes.rb', line 15 def business_vehicle_pick_up_date @business_vehicle_pick_up_date&.strftime( GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS ) end |
#business_vehicle_pick_up_date=(value) ⇒ Object
The date when customer takes the vehicle
22 23 24 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/business/car_plane_and_boat_rentals_attributes.rb', line 22 def business_vehicle_pick_up_date=(value) parse_date attribute: __method__, value: value, allow_empty: true end |
#business_vehicle_return_date ⇒ Object
The date when the customer returns the vehicle back
27 28 29 30 31 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/business/car_plane_and_boat_rentals_attributes.rb', line 27 def business_vehicle_return_date @business_vehicle_return_date&.strftime( GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS ) end |
#business_vehicle_return_date=(value) ⇒ Object
The date when the customer returns the vehicle back
34 35 36 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/business/car_plane_and_boat_rentals_attributes.rb', line 34 def business_vehicle_return_date=(value) parse_date attribute: __method__, value: value, allow_empty: true end |