Module: GenesisRuby::Api::Mixins::Requests::Financial::Threeds::Version2::MerchantRisk
- Included in:
- CommonAttributes, WpfAttributes
- Defined in:
- lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb
Overview
Mixin ThreedsV2 MerchantRisk
Instance Attribute Summary collapse
-
#threeds_v2_merchant_risk_delivery_timeframe ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_delivery_timeframe.
-
#threeds_v2_merchant_risk_gift_card ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_gift_card.
-
#threeds_v2_merchant_risk_gift_card_count ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_gift_card_count.
-
#threeds_v2_merchant_risk_pre_order_purchase_indicator ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_pre_order_purchase_indicator.
-
#threeds_v2_merchant_risk_reorder_items_indicator ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_reorder_items_indicator.
-
#threeds_v2_merchant_risk_shipping_indicator ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_shipping_indicator.
Instance Method Summary collapse
-
#threeds_v2_merchant_risk_pre_order_date ⇒ Object
For a pre-ordered purchase, the expected date that the merchandise will be available.
-
#threeds_v2_merchant_risk_pre_order_date=(value) ⇒ Object
For a pre-ordered purchase, the expected date that the merchandise will be available.
Instance Attribute Details
#threeds_v2_merchant_risk_delivery_timeframe ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_delivery_timeframe.
19 20 21 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb', line 19 def threeds_v2_merchant_risk_delivery_timeframe @threeds_v2_merchant_risk_delivery_timeframe end |
#threeds_v2_merchant_risk_gift_card ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_gift_card.
19 20 21 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb', line 19 def threeds_v2_merchant_risk_gift_card @threeds_v2_merchant_risk_gift_card end |
#threeds_v2_merchant_risk_gift_card_count ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_gift_card_count.
18 19 20 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb', line 18 def threeds_v2_merchant_risk_gift_card_count @threeds_v2_merchant_risk_gift_card_count end |
#threeds_v2_merchant_risk_pre_order_purchase_indicator ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_pre_order_purchase_indicator.
19 20 21 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb', line 19 def threeds_v2_merchant_risk_pre_order_purchase_indicator @threeds_v2_merchant_risk_pre_order_purchase_indicator end |
#threeds_v2_merchant_risk_reorder_items_indicator ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_reorder_items_indicator.
19 20 21 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb', line 19 def threeds_v2_merchant_risk_reorder_items_indicator @threeds_v2_merchant_risk_reorder_items_indicator end |
#threeds_v2_merchant_risk_shipping_indicator ⇒ Object
Returns the value of attribute threeds_v2_merchant_risk_shipping_indicator.
19 20 21 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb', line 19 def threeds_v2_merchant_risk_shipping_indicator @threeds_v2_merchant_risk_shipping_indicator end |
Instance Method Details
#threeds_v2_merchant_risk_pre_order_date ⇒ Object
For a pre-ordered purchase, the expected date that the merchandise will be available
26 27 28 29 30 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb', line 26 def threeds_v2_merchant_risk_pre_order_date @threeds_v2_merchant_risk_pre_order_date&.strftime( GenesisRuby::Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS ) end |
#threeds_v2_merchant_risk_pre_order_date=(value) ⇒ Object
For a pre-ordered purchase, the expected date that the merchandise will be available
33 34 35 |
# File 'lib/genesis_ruby/api/mixins/requests/financial/threeds/version2/merchant_risk.rb', line 33 def threeds_v2_merchant_risk_pre_order_date=(value) parse_date attribute: __method__, value: value, allow_empty: true end |