Class: GenesisRuby::Api::Requests::Financial::CashPayments::Cash
- Inherits:
-
Base::Financial
- Object
- GenesisRuby::Api::Request
- Base::Financial
- GenesisRuby::Api::Requests::Financial::CashPayments::Cash
- Includes:
- Mixins::Requests::AddressInfoAttributes, Mixins::Requests::DocumentAttributes, Mixins::Requests::Financial::AsyncAttributes
- Defined in:
- lib/genesis_ruby/api/requests/financial/cash_payments/cash.rb
Overview
Cash payment methods allow customers to pay bills and online purchases in cash at convenient physical locations such as stores, banks, ATMs, even pharmacies in some countries.
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#payment_type ⇒ Object
Returns the value of attribute payment_type.
Attributes included from Mixins::Requests::Financial::AsyncAttributes
#return_failure_url, #return_success_url
Attributes included from Mixins::Requests::DocumentAttributes
Attributes included from Mixins::Requests::CustomerAddress::CustomerInfoAttributes
#customer_email, #customer_phone
Attributes included from Mixins::Requests::CustomerAddress::ShippingInfoAttributes
#shipping_address1, #shipping_address2, #shipping_city, #shipping_country, #shipping_first_name, #shipping_last_name, #shipping_neighborhood, #shipping_state, #shipping_zip_code
Attributes included from Mixins::Requests::CustomerAddress::BillingInfoAttributes
#billing_address1, #billing_address2, #billing_city, #billing_country, #billing_first_name, #billing_last_name, #billing_neighborhood, #billing_state, #billing_zip_code
Attributes included from Mixins::Requests::Financial::PaymentAttributes
Attributes included from Mixins::Requests::Financial::BaseAttributes
#remote_ip, #transaction_id, #usage
Attributes inherited from GenesisRuby::Api::Request
Method Summary
Methods included from Mixins::Requests::SmartRouterAttributes
#use_smart_router, #use_smart_router=
Methods inherited from GenesisRuby::Api::Request
Constructor Details
This class inherits a constructor from GenesisRuby::Api::Request
Instance Attribute Details
#payment_type ⇒ Object
Returns the value of attribute payment_type.
18 19 20 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/cash.rb', line 18 def payment_type @payment_type end |