Class: GenesisRuby::Api::Requests::Financial::CashPayments::Pix
- Inherits:
-
Base::Financial
- Object
- GenesisRuby::Api::Request
- Base::Financial
- GenesisRuby::Api::Requests::Financial::CashPayments::Pix
- Includes:
- Mixins::Requests::AddressInfoAttributes, Mixins::Requests::BirthDateAttributes, Mixins::Requests::DocumentAttributes, Mixins::Requests::Financial::AsyncAttributes, Mixins::Requests::Financial::BeneficiaryAttributes, Mixins::Requests::Financial::OnlineBankingPayments::PixAttributes, Mixins::Requests::Financial::PendingPaymentAttributes
- Defined in:
- lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb
Overview
Pix is a payment service, which represents a new way of receiving/sending money. Pix allows payments to be made instantly.
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#birth_city ⇒ Object
Returns the value of attribute birth_city.
-
#birth_state ⇒ Object
Returns the value of attribute birth_state.
-
#country_of_origin ⇒ Object
Returns the value of attribute country_of_origin.
-
#gender ⇒ Object
Returns the value of attribute gender.
-
#marital_status ⇒ Object
Returns the value of attribute marital_status.
-
#nationality ⇒ Object
Returns the value of attribute nationality.
-
#sender_occupation ⇒ Object
Returns the value of attribute sender_occupation.
Attributes included from Mixins::Requests::Financial::PendingPaymentAttributes
Attributes included from Mixins::Requests::Financial::OnlineBankingPayments::PixAttributes
#company_activity, #company_type, #mothers_name
Attributes included from Mixins::Requests::Financial::BeneficiaryAttributes
#beneficiary_document_id, #beneficiary_name, #beneficiary_pix_key
Attributes included from Mixins::Requests::Financial::AsyncAttributes
#return_failure_url, #return_success_url
Attributes included from Mixins::Requests::DocumentAttributes
Attributes included from Mixins::Requests::CustomerAddress::CustomerInfoAttributes
#customer_email, #customer_phone
Attributes included from Mixins::Requests::CustomerAddress::ShippingInfoAttributes
#shipping_address1, #shipping_address2, #shipping_city, #shipping_country, #shipping_first_name, #shipping_last_name, #shipping_neighborhood, #shipping_state, #shipping_zip_code
Attributes included from Mixins::Requests::CustomerAddress::BillingInfoAttributes
#billing_address1, #billing_address2, #billing_city, #billing_first_name, #billing_last_name, #billing_neighborhood, #billing_state, #billing_zip_code
Attributes included from Mixins::Requests::Financial::PaymentAttributes
Attributes included from Mixins::Requests::Financial::BaseAttributes
#remote_ip, #transaction_id, #usage
Attributes inherited from GenesisRuby::Api::Request
Instance Method Summary collapse
-
#billing_country ⇒ Object
Billing Country custom accessor.
-
#incorporation_date ⇒ Object
Override incorpocation date with specific format for Pix request.
Methods included from Mixins::Requests::Financial::OnlineBankingPayments::PixAttributes
Methods included from Mixins::Requests::BirthDateAttributes
Methods included from Mixins::Requests::SmartRouterAttributes
#use_smart_router, #use_smart_router=
Methods inherited from GenesisRuby::Api::Request
Constructor Details
This class inherits a constructor from GenesisRuby::Api::Request
Instance Attribute Details
#birth_city ⇒ Object
Returns the value of attribute birth_city.
24 25 26 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24 def birth_city @birth_city end |
#birth_state ⇒ Object
Returns the value of attribute birth_state.
24 25 26 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24 def birth_state @birth_state end |
#country_of_origin ⇒ Object
Returns the value of attribute country_of_origin.
24 25 26 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24 def country_of_origin @country_of_origin end |
#gender ⇒ Object
Returns the value of attribute gender.
24 25 26 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24 def gender @gender end |
#marital_status ⇒ Object
Returns the value of attribute marital_status.
24 25 26 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24 def marital_status @marital_status end |
#nationality ⇒ Object
Returns the value of attribute nationality.
24 25 26 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24 def nationality @nationality end |
#sender_occupation ⇒ Object
Returns the value of attribute sender_occupation.
24 25 26 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 24 def sender_occupation @sender_occupation end |
Instance Method Details
#billing_country ⇒ Object
Billing Country custom accessor
28 29 30 31 32 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 28 def billing_country return nil unless @billing_country @billing_country.to_s.upcase end |
#incorporation_date ⇒ Object
Override incorpocation date with specific format for Pix request
35 36 37 |
# File 'lib/genesis_ruby/api/requests/financial/cash_payments/pix.rb', line 35 def incorporation_date @incorporation_date&.strftime Api::Constants::DateTimeFormats::DD_MM_YYYY_L_HYPHENS end |