Class: GenesisRuby::Api::Requests::NonFinancial::Kyc::Verifications::AddressByDocumentProof
- Inherits:
-
Base::NonFinancial::Kyc::Base
- Object
- GenesisRuby::Api::Request
- Base::Versioned
- Base::NonFinancial::Kyc::Base
- GenesisRuby::Api::Requests::NonFinancial::Kyc::Verifications::AddressByDocumentProof
- Defined in:
- lib/genesis_ruby/api/requests/non_financial/kyc/verifications/address_by_document_proof.rb
Overview
Address Verification by Document Proof Verification of customer address using a document.
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#backside_proof_required ⇒ Object
Returns the value of attribute backside_proof_required.
-
#reference_id ⇒ Object
Returns the value of attribute reference_id.
-
#with_async_workflow ⇒ Object
Returns the value of attribute with_async_workflow.
-
#with_enhanced_address_verification ⇒ Object
Returns the value of attribute with_enhanced_address_verification.
Attributes included from Mixins::Requests::NonFinancial::Kyc::DocumentAttributes
#additional_proof, #first_name, #full_address, #last_name, #middle_name, #proof
Attributes inherited from Base::Versioned
Attributes inherited from GenesisRuby::Api::Request
Instance Method Summary collapse
-
#document_supported_types ⇒ Object
Supported types of document that can be verified for address verification.
-
#document_supported_types=(value) ⇒ Object
Supported types of document that can be verified for address verification.
-
#initialize(configuration, _builder_interface = nil) ⇒ AddressByDocumentProof
constructor
Initializes the Address Verification by Document Proof Request.
Methods included from Mixins::Requests::NonFinancial::Kyc::DocumentAttributes
#date_of_birth, #date_of_birth=
Methods inherited from Base::NonFinancial::Kyc::Base
Methods inherited from GenesisRuby::Api::Request
Constructor Details
#initialize(configuration, _builder_interface = nil) ⇒ AddressByDocumentProof
Initializes the Address Verification by Document Proof Request
34 35 36 37 38 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/address_by_document_proof.rb', line 34 def initialize(configuration, _builder_interface = nil) super configuration self.request_path = 'verifications/address/by_proof' end |
Instance Attribute Details
#backside_proof_required ⇒ Object
Returns the value of attribute backside_proof_required.
18 19 20 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/address_by_document_proof.rb', line 18 def backside_proof_required @backside_proof_required end |
#reference_id ⇒ Object
Returns the value of attribute reference_id.
17 18 19 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/address_by_document_proof.rb', line 17 def reference_id @reference_id end |
#with_async_workflow ⇒ Object
Returns the value of attribute with_async_workflow.
18 19 20 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/address_by_document_proof.rb', line 18 def with_async_workflow @with_async_workflow end |
#with_enhanced_address_verification ⇒ Object
Returns the value of attribute with_enhanced_address_verification.
18 19 20 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/address_by_document_proof.rb', line 18 def with_enhanced_address_verification @with_enhanced_address_verification end |
Instance Method Details
#document_supported_types ⇒ Object
Supported types of document that can be verified for address verification
29 30 31 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/address_by_document_proof.rb', line 29 def document_supported_types @document_supported_types || [] end |
#document_supported_types=(value) ⇒ Object
Supported types of document that can be verified for address verification
21 22 23 24 25 26 |
# File 'lib/genesis_ruby/api/requests/non_financial/kyc/verifications/address_by_document_proof.rb', line 21 def document_supported_types=(value) parse_array_of_strings attribute: __method__, value: value, allowed: Api::Constants::NonFinancial::Kyc::AddressDocumentSupportedTypes.all, allow_empty: true end |