Class: GenesisRuby::Api::Requests::NonFinancial::Reconcile::Transaction
- Inherits:
-
GenesisRuby::Api::Request
- Object
- GenesisRuby::Api::Request
- GenesisRuby::Api::Requests::NonFinancial::Reconcile::Transaction
- Includes:
- Mixins::Requests::SmartRouterAttributes
- Defined in:
- lib/genesis_ruby/api/requests/non_financial/reconcile/transaction.rb
Overview
Reconcile can be used to retrieve data about a transaction. This can be useful if you want to retrieve information about a transaction whose status is timeout, which returned an error or has changed eg. has beed chargebacked.
Constant Summary
Constants inherited from GenesisRuby::Api::Request
GenesisRuby::Api::Request::AUTH_TYPE_BASIC, GenesisRuby::Api::Request::AUTH_TYPE_TOKEN, GenesisRuby::Api::Request::METHOD_DELETE, GenesisRuby::Api::Request::METHOD_GET, GenesisRuby::Api::Request::METHOD_PATCH, GenesisRuby::Api::Request::METHOD_POST, GenesisRuby::Api::Request::METHOD_PUT, GenesisRuby::Api::Request::PORT_HTTPS, GenesisRuby::Api::Request::PROTOCOL_HTTPS
Instance Attribute Summary collapse
-
#arn ⇒ Object
Returns the value of attribute arn.
-
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
-
#unique_id ⇒ Object
Returns the value of attribute unique_id.
Attributes inherited from GenesisRuby::Api::Request
Method Summary
Methods included from Mixins::Requests::SmartRouterAttributes
#use_smart_router, #use_smart_router=
Methods inherited from GenesisRuby::Api::Request
Constructor Details
This class inherits a constructor from GenesisRuby::Api::Request
Instance Attribute Details
#arn ⇒ Object
Returns the value of attribute arn.
15 16 17 |
# File 'lib/genesis_ruby/api/requests/non_financial/reconcile/transaction.rb', line 15 def arn @arn end |
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
15 16 17 |
# File 'lib/genesis_ruby/api/requests/non_financial/reconcile/transaction.rb', line 15 def transaction_id @transaction_id end |
#unique_id ⇒ Object
Returns the value of attribute unique_id.
15 16 17 |
# File 'lib/genesis_ruby/api/requests/non_financial/reconcile/transaction.rb', line 15 def unique_id @unique_id end |